@@ -24,9 +24,8 @@
 #define __GST_LADSPA_H__
 
 
-#include <config.h>
 #include <gst/gst.h>
-#include <gst/gstbytestream.h>
+#include <gst/bytestream/bytestream.h>
 
 #include "ladspa.h"
 
@@ -60,8 +59,6 @@ struct _GstLADSPA {
   GstPad **sinkpads, 
          **srcpads;
 
-  GstBufferPool *bufpool;
-
   gboolean activated;
 
   gint samplerate, buffer_frames;
