@@ -47,7 +47,8 @@ typedef enum
   GST_ID3_TAG_STATE_SEEKING_TO_NORMAL,
   GST_ID3_TAG_STATE_NORMAL_START,
   GST_ID3_TAG_STATE_NORMAL,
-} GstID3TagState;
+}
+GstID3TagState;
 
 typedef enum
 {
@@ -55,7 +56,8 @@ typedef enum
   GST_ID3_TAG_PARSE_TAG,
   GST_ID3_TAG_PARSE_WRITE,
   GST_ID3_TAG_PARSE_PARSE
-} GstID3ParseMode;
+}
+GstID3ParseMode;
 
 struct _GstID3Tag
 {
@@ -116,6 +118,8 @@ enum
       /* FILL ME */
 };
 
+GST_DEBUG_CATEGORY_EXTERN (mad_debug);
+
 static GstStaticPadTemplate id3_tag_src_template_factory =
 GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
@@ -351,6 +355,7 @@ gst_id3_tag_get_event_masks (GstPad * pad)
     {GST_EVENT_SEEK, GST_SEEK_METHOD_SET | GST_SEEK_FLAG_FLUSH},
     {0,}
   };
+
   return gst_id3_tag_src_event_masks;
 }
 static const GstQueryType *
@@ -361,6 +366,7 @@ gst_id3_tag_get_query_types (GstPad * pad)
     GST_QUERY_POSITION,
     0
   };
+
   return gst_id3_tag_src_query_types;
 }
 
@@ -432,7 +438,7 @@ gst_id3_tag_src_event (GstPad * pad, GstEvent * event)
 
         switch (GST_EVENT_SEEK_METHOD (event)) {
           case GST_SEEK_METHOD_SET:
-            diff = tag->v2tag_size_new - tag->v2tag_size;
+            diff = tag->v2tag_size - tag->v2tag_size_new;
             break;
           case GST_SEEK_METHOD_CUR:
             break;
@@ -642,6 +648,7 @@ tag_list_to_id3_tag_foreach (const GstTagList * list, const gchar * tag_name,
     }
     if (id3_field_addstring (field, (id3_ucs4_t *) put) != 0) {
       GST_WARNING ("could not add a string to id3 tag field");
+      g_free (put);
       return;
     }
   }
@@ -688,19 +695,22 @@ gst_id3_tag_handle_event (GstPad * pad, GstEvent * event)
         case GST_ID3_TAG_STATE_READING_V2_TAG:{
           guint64 value;
 
-          gst_event_discont_get_value (event, GST_FORMAT_BYTES, &value);
-          if (value !=
-              (tag->buffer ? GST_BUFFER_OFFSET (tag->buffer) +
-                  GST_BUFFER_SIZE (tag->buffer)
-                  : 0))
-            GST_ELEMENT_ERROR (tag, CORE, EVENT, (NULL),
-                ("Seek during ID3v2 tag reading"));
+          if (gst_event_discont_get_value (event, GST_FORMAT_BYTES, &value) ||
+              gst_event_discont_get_value (event, GST_FORMAT_DEFAULT, &value)) {
+            if (value !=
+                (tag->buffer ? GST_BUFFER_OFFSET (tag->buffer) +
+                    GST_BUFFER_SIZE (tag->buffer)
+                    : 0))
+              GST_ELEMENT_ERROR (tag, CORE, EVENT, (NULL),
+                  ("Seek during ID3v2 tag reading"));
+          }
           gst_data_unref (GST_DATA (event));
           break;
         }
         case GST_ID3_TAG_STATE_SEEKING_TO_V1_TAG:
           /* just assume it's the right seek for now */
           gst_id3_tag_set_state (tag, GST_ID3_TAG_STATE_READING_V1_TAG);
+          gst_data_unref (GST_DATA (event));
           break;
         case GST_ID3_TAG_STATE_READING_V1_TAG:
           GST_ELEMENT_ERROR (tag, CORE, EVENT, (NULL),
@@ -710,6 +720,7 @@ gst_id3_tag_handle_event (GstPad * pad, GstEvent * event)
         case GST_ID3_TAG_STATE_SEEKING_TO_NORMAL:
           /* just assume it's the right seek for now */
           gst_id3_tag_set_state (tag, GST_ID3_TAG_STATE_NORMAL_START);
+          gst_data_unref (GST_DATA (event));
           break;
         case GST_ID3_TAG_STATE_NORMAL_START:
           GST_ERROR_OBJECT (tag, "tag event not sent, FIXME");
@@ -721,7 +732,8 @@ gst_id3_tag_handle_event (GstPad * pad, GstEvent * event)
 
           if (gst_event_discont_get_value (event, GST_FORMAT_BYTES, &value)) {
             value += tag->v1tag_size;
-            new = gst_event_new_discontinuous (GST_FORMAT_BYTES, value, 0);
+            new =
+                gst_event_new_discontinuous (FALSE, GST_FORMAT_BYTES, value, 0);
             gst_data_unref (GST_DATA (event));
             gst_pad_push (tag->srcpad, GST_DATA (new));
           } else {
@@ -775,7 +787,8 @@ typedef struct
   guint best_probability;
   GstCaps *caps;
   GstBuffer *buffer;
-} SimpleTypeFind;
+}
+SimpleTypeFind;
 guint8 *
 simple_find_peek (gpointer data, gint64 offset, guint size)
 {
@@ -1149,9 +1162,12 @@ plugin_init (GstPlugin * plugin)
   if (!gst_library_load ("gsttags"))
     return FALSE;
 
+  /* We register id3tag with a rank one less than mad so that mad always
+     gets picked before id3tag if possible.  This avoids multiple plugging
+     of id3tag in the autoplugger for now. */
   if (!gst_element_register (plugin, "mad", GST_RANK_PRIMARY,
           gst_mad_get_type ())
-      || !gst_element_register (plugin, "id3tag", GST_RANK_PRIMARY,
+      || !gst_element_register (plugin, "id3tag", GST_RANK_PRIMARY - 1,
           gst_id3_tag_get_type ()))
     return FALSE;
 
