@@ -40,6 +40,8 @@ typedef gint mpeg2_state_t;
 #endif
 
 GST_DEBUG_CATEGORY_EXTERN (GST_CAT_SEEK);
+GST_DEBUG_CATEGORY_STATIC (mpeg2dec_debug);
+#define GST_CAT_DEFAULT (mpeg2dec_debug)
 
 /* elementfactory information */
 static GstElementDetails gst_mpeg2dec_details = {
@@ -67,7 +69,7 @@ GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("video/x-raw-yuv, "
-        "format = (fourcc) { YV12, I420 }, "
+        "format = (fourcc) { YV12, I420, Y42B }, "
         "width = (int) [ 16, 4096 ], "
         "height = (int) [ 16, 4096 ], "
         "pixel_width = (int) [ 1, 255 ], "
@@ -143,10 +145,15 @@ gst_mpeg2dec_get_type (void)
       0,
       (GInstanceInitFunc) gst_mpeg2dec_init,
     };
+
     mpeg2dec_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstMpeg2dec", &mpeg2dec_info,
         0);
   }
+
+  GST_DEBUG_CATEGORY_INIT (mpeg2dec_debug, "mpeg2dec", 0,
+      "MPEG2 decoder element");
+
   return mpeg2dec_type;
 }
 
@@ -290,20 +297,35 @@ gst_mpeg2dec_alloc_buffer (GstMpeg2dec * mpeg2dec, const mpeg2_info_t * info,
   guint8 *buf[3], *out;
   const mpeg2_picture_t *picture;
 
-  outbuf = gst_buffer_new_and_alloc ((size * 3) / 2);
+  if (mpeg2dec->format == MPEG2DEC_FORMAT_I422) {
+    outbuf = gst_buffer_new_and_alloc (size * 2);
 
-  out = GST_BUFFER_DATA (outbuf);
+    out = GST_BUFFER_DATA (outbuf);
 
-  buf[0] = out;
-  if (mpeg2dec->format == MPEG2DEC_FORMAT_I420) {
+    buf[0] = out;
     buf[1] = buf[0] + size;
-    buf[2] = buf[1] + size / 4;
+    buf[2] = buf[1] + size / 2;
+
   } else {
-    buf[2] = buf[0] + size;
-    buf[1] = buf[2] + size / 4;
+    outbuf = gst_buffer_new_and_alloc ((size * 3) / 2);
+
+    out = GST_BUFFER_DATA (outbuf);
+
+    buf[0] = out;
+    if (mpeg2dec->format == MPEG2DEC_FORMAT_I420) {
+      buf[0] = out;
+      buf[1] = buf[0] + size;
+      buf[2] = buf[1] + size / 4;
+    } else {
+      buf[0] = out;
+      buf[2] = buf[0] + size;
+      buf[1] = buf[2] + size / 4;
+    }
   }
 
   gst_buffer_ref (outbuf);
+
+  mpeg2_custom_fbuf (mpeg2dec->decoder, 1);
   mpeg2_set_buf (mpeg2dec->decoder, buf, outbuf);
 
   picture = info->current_picture;
@@ -325,16 +347,32 @@ static gboolean
 gst_mpeg2dec_negotiate_format (GstMpeg2dec * mpeg2dec)
 {
   GstCaps *caps;
-  guint32 fourcc;
+  guint32 fourcc, myFourcc;
   gboolean ret;
+  const mpeg2_info_t *info;
+  const mpeg2_sequence_t *sequence;
 
   if (!GST_PAD_IS_LINKED (mpeg2dec->srcpad)) {
     mpeg2dec->format = MPEG2DEC_FORMAT_I420;
     return TRUE;
   }
 
+  info = mpeg2_info (mpeg2dec->decoder);
+  sequence = info->sequence;
+
+  if (sequence->width != sequence->chroma_width &&
+      sequence->height != sequence->chroma_height)
+    myFourcc = GST_STR_FOURCC ("I420");
+  else if (sequence->width == sequence->chroma_width ||
+      sequence->height == sequence->chroma_height)
+    myFourcc = GST_STR_FOURCC ("Y42B");
+  else {
+    g_warning ("mpeg2dec: 4:4:4 format not yet supported");
+    return (FALSE);
+  }
+
   caps = gst_caps_new_simple ("video/x-raw-yuv",
-      "format", GST_TYPE_FOURCC, GST_STR_FOURCC ("I420"),
+      "format", GST_TYPE_FOURCC, myFourcc,
       "width", G_TYPE_INT, mpeg2dec->width,
       "height", G_TYPE_INT, mpeg2dec->height,
       "pixel_width", G_TYPE_INT, mpeg2dec->pixel_width,
@@ -350,7 +388,9 @@ gst_mpeg2dec_negotiate_format (GstMpeg2dec * mpeg2dec)
   gst_structure_get_fourcc (gst_caps_get_structure (caps, 0),
       "format", &fourcc);
 
-  if (fourcc == GST_STR_FOURCC ("I420")) {
+  if (fourcc == GST_STR_FOURCC ("Y42B")) {
+    mpeg2dec->format = MPEG2DEC_FORMAT_I422;
+  } else if (fourcc == GST_STR_FOURCC ("I420")) {
     mpeg2dec->format = MPEG2DEC_FORMAT_I420;
   } else {
     mpeg2dec->format = MPEG2DEC_FORMAT_YV12;
@@ -439,6 +479,7 @@ gst_mpeg2dec_chain (GstPad * pad, GstData * _data)
           gst_index_commit (mpeg2dec->index, mpeg2dec->index_id);
         }
       default:
+        GST_DEBUG ("Got event of type %d on sink pad", GST_EVENT_TYPE (event));
         gst_pad_event_default (pad, event);
         return;
     }
@@ -464,17 +505,17 @@ gst_mpeg2dec_chain (GstPad * pad, GstData * _data)
     mpeg2_pts (mpeg2dec->decoder, mpeg_pts);
 #endif
   } else {
-    GST_DEBUG ("no pts");
+    GST_LOG ("no pts");
   }
 
-  GST_DEBUG ("calling _buffer");
+  GST_LOG ("calling mpeg2_buffer");
   mpeg2_buffer (mpeg2dec->decoder, data, end);
-  GST_DEBUG ("calling _buffer done");
+  GST_LOG ("calling mpeg2_buffer done");
 
   while (!done) {
     gboolean slice = FALSE;
 
-    GST_DEBUG ("calling parse");
+    GST_LOG ("calling parse");
     state = mpeg2_parse (mpeg2dec->decoder);
     GST_DEBUG ("parse state %d", state);
     switch (state) {
@@ -612,7 +653,6 @@ gst_mpeg2dec_chain (GstPad * pad, GstData * _data)
           mpeg2dec->next_time +=
               (mpeg2dec->frame_period * picture->nb_fields) >> 1;
 
-
           GST_DEBUG ("picture: %s %s fields:%d off:%" G_GINT64_FORMAT " ts:%"
               G_GINT64_FORMAT,
               (picture->flags & PIC_FLAG_TOP_FIELD_FIRST ? "tff " : "    "),
@@ -627,7 +667,6 @@ gst_mpeg2dec_chain (GstPad * pad, GstData * _data)
                 GST_FORMAT_TIME, GST_BUFFER_TIMESTAMP (outbuf), 0);
           }
 
-
           if (picture->flags & PIC_FLAG_SKIP ||
               !GST_PAD_IS_USABLE (mpeg2dec->srcpad) ||
               mpeg2dec->discont_state != MPEG2DEC_DISC_NONE ||
@@ -638,7 +677,10 @@ gst_mpeg2dec_chain (GstPad * pad, GstData * _data)
             GST_BUFFER_DURATION (outbuf) = mpeg2dec->frame_period;
             gst_pad_push (mpeg2dec->srcpad, GST_DATA (outbuf));
           }
+        } else if (info->display_fbuf && !info->display_fbuf->id) {
+          GST_WARNING ("Got a frame from libmpeg2, but it has no buffer");
         }
+
         if (info->discard_fbuf && info->discard_fbuf->id) {
           gst_buffer_unref ((GstBuffer *) info->discard_fbuf->id);
         }
@@ -689,6 +731,7 @@ gst_mpeg2dec_get_sink_formats (GstPad * pad)
     GST_FORMAT_TIME,
     0
   };
+
   return formats;
 }
 
@@ -745,6 +788,7 @@ gst_mpeg2dec_get_src_formats (GstPad * pad)
     GST_FORMAT_DEFAULT,
     0
   };
+
   return formats;
 }
 
@@ -812,6 +856,7 @@ gst_mpeg2dec_get_src_query_types (GstPad * pad)
     GST_QUERY_POSITION,
     0
   };
+
   return types;
 }
 
@@ -895,6 +940,7 @@ gst_mpeg2dec_get_src_event_masks (GstPad * pad)
     {GST_EVENT_NAVIGATION, GST_EVENT_FLAG_NONE},
     {0,}
   };
+
   return masks;
 }
 
