@@ -52,7 +52,8 @@ typedef enum
   GST_OGG_STATE_SEEK,
   /* normal playback */
   GST_OGG_STATE_PLAY
-} GstOggState;
+}
+GstOggState;
 
 /* all information needed for one ogg stream */
 typedef struct
@@ -69,7 +70,8 @@ typedef struct
   glong pages;                  /* number of pages in stream or 0 */
 
   guint flags;
-} GstOggPad;
+}
+GstOggPad;
 
 typedef enum
 {
@@ -82,14 +84,17 @@ GstOggPadFlags;
 typedef struct
 {
   GSList *pads;                 /* list of GstOggPad */
-} GstOggChain;
+}
+GstOggChain;
 
 #define CURRENT_CHAIN(ogg) (&g_array_index ((ogg)->chains, GstOggChain, (ogg)->current_chain))
 #define FOR_PAD_IN_CURRENT_CHAIN(ogg, _pad, ...) G_STMT_START{			\
   GSList *_walk;							      	\
-  for (_walk = CURRENT_CHAIN (ogg)->pads; _walk; _walk = g_slist_next (_walk)) { \
-    GstOggPad *_pad = (GstOggPad *) _walk->data;				\
-    __VA_ARGS__									\
+  if ((ogg)->current_chain != -1) {						\
+    for (_walk = CURRENT_CHAIN (ogg)->pads; _walk; _walk = g_slist_next (_walk)) { \
+      GstOggPad *_pad = (GstOggPad *) _walk->data;				\
+      __VA_ARGS__								\
+    }										\
   }										\
 }G_STMT_END
 
@@ -98,7 +103,8 @@ typedef enum
   GST_OGG_FLAG_BOS = GST_ELEMENT_FLAG_LAST,
   GST_OGG_FLAG_EOS,
   GST_OGG_FLAG_WAIT_FOR_DISCONT
-} GstOggFlag;
+}
+GstOggFlag;
 
 struct _GstOggDemux
 {
@@ -250,6 +256,7 @@ gst_ogg_demux_get_event_masks (GstPad * pad)
     {GST_EVENT_SEEK, GST_SEEK_METHOD_SET | GST_SEEK_FLAG_FLUSH},
     {0,}
   };
+
   return gst_ogg_demux_src_event_masks;
 }
 static const GstQueryType *
@@ -260,6 +267,7 @@ gst_ogg_demux_get_query_types (GstPad * pad)
     GST_QUERY_POSITION,
     0
   };
+
   return gst_ogg_demux_src_query_types;
 }
 
@@ -368,8 +376,7 @@ gst_ogg_demux_src_event (GstPad * pad, GstEvent * event)
 
       GST_OGG_SET_STATE (ogg, GST_OGG_STATE_SEEK);
       FOR_PAD_IN_CURRENT_CHAIN (ogg, pad,
-          pad->flags |= GST_OGG_PAD_NEEDS_DISCONT;
-          );
+          pad->flags |= GST_OGG_PAD_NEEDS_DISCONT;);
       GST_DEBUG_OBJECT (ogg, "initiating seeking to offset %" G_GUINT64_FORMAT,
           offset);
       ogg->seek_pad = cur;
@@ -416,8 +423,7 @@ gst_ogg_demux_handle_event (GstPad * pad, GstEvent * event)
       gst_event_unref (event);
       GST_FLAG_UNSET (ogg, GST_OGG_FLAG_WAIT_FOR_DISCONT);
       FOR_PAD_IN_CURRENT_CHAIN (ogg, pad,
-          pad->flags |= GST_OGG_PAD_NEEDS_DISCONT;
-          );
+          pad->flags |= GST_OGG_PAD_NEEDS_DISCONT;);
       break;
     case GST_EVENT_EOS:
       if (ogg->state == GST_OGG_STATE_SETUP) {
@@ -800,7 +806,7 @@ gst_ogg_pad_push (GstOggDemux * ogg, GstOggPad * pad)
         if ((pad->flags & GST_OGG_PAD_NEEDS_DISCONT)
             && GST_PAD_IS_USABLE (pad->pad)) {
           GstEvent *event = gst_event_new_discontinuous (FALSE,
-              GST_FORMAT_DEFAULT, pad->known_offset);   /* FIXME: this might be wrong because we can only use the last known offset */
+              GST_FORMAT_DEFAULT, pad->known_offset, GST_FORMAT_UNDEFINED);     /* FIXME: this might be wrong because we can only use the last known offset */
 
           gst_pad_push (pad->pad, GST_DATA (event));
           pad->flags &= (~GST_OGG_PAD_NEEDS_DISCONT);
@@ -899,7 +905,8 @@ typedef struct
   ogg_packet *packet;
   guint best_probability;
   GstCaps *caps;
-} OggTypeFind;
+}
+OggTypeFind;
 static guint8 *
 ogg_find_peek (gpointer data, gint64 offset, guint size)
 {
