@@ -1,4 +1,4 @@
-/* GStreamer xvid decoder plugin
+/* GStreamer xvid encoder/decoder plugin
  * Copyright (C) 2003 Ronald Bultje <rbultje@ronald.bitfreak.net>
  *
  * This library is free software; you can redistribute it and/or
@@ -22,15 +22,33 @@
 
 #include <gst/gst.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
+
+#define gst_xvid_init_struct(s) \
+  do { \
+    memset (&s, 0, sizeof(s)); \
+    s.version = XVID_VERSION; \
+  } while (0);
+
+#define RGB_24_32_STATIC_CAPS(bpp, r_mask,g_mask,b_mask) \
+  "video/x-raw-rgb, " \
+  "width = (int) [ 0, MAX ], " \
+  "height = (int) [ 0, MAX], " \
+  "framerate = (double) [ 0.0, MAX], " \
+  "depth = (int) 24, " \
+  "bpp = (int) " G_STRINGIFY (bpp) ", " \
+  "endianness = (int) BIG_ENDIAN, " \
+  "red_mask = (int) " G_STRINGIFY (r_mask) ", " \
+  "green_mask = (int) " G_STRINGIFY (g_mask) ", " \
+  "blue_mask = (int) " G_STRINGIFY (b_mask)
 
 extern gchar *	gst_xvid_error (int errorcode);
 extern gboolean	gst_xvid_init  (void);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+extern gint     gst_xvid_structure_to_csp (GstStructure *structure,
+					   gint w, gint *stride, gint *bpp);
+extern GstCaps *gst_xvid_csp_to_caps      (gint csp, gint w, gint h, gdouble fps);
+
+G_END_DECLS
 
 #endif /* __GST_XVID_H__ */
