@@ -26,14 +26,15 @@
 #include "mixer.h"
 #include "mixer-marshal.h"
 
-enum {
+enum
+{
   MUTE_TOGGLED,
   RECORD_TOGGLED,
   VOLUME_CHANGED,
   LAST_SIGNAL
 };
 
-static void 	gst_mixer_class_init	(GstMixerClass *klass);
+static void gst_mixer_class_init (GstMixerClass * klass);
 
 static guint gst_mixer_signals[LAST_SIGNAL] = { 0 };
 
@@ -56,48 +57,47 @@ gst_mixer_get_type (void)
     };
 
     gst_mixer_type = g_type_register_static (G_TYPE_INTERFACE,
-					     "GstMixer",
-					     &gst_mixer_info, 0);
+        "GstMixer", &gst_mixer_info, 0);
     g_type_interface_add_prerequisite (gst_mixer_type,
-				       GST_TYPE_IMPLEMENTS_INTERFACE);
+        GST_TYPE_IMPLEMENTS_INTERFACE);
   }
 
   return gst_mixer_type;
 }
 
 static void
-gst_mixer_class_init (GstMixerClass *klass)
+gst_mixer_class_init (GstMixerClass * klass)
 {
   static gboolean initialized = FALSE;
-  
+
   if (!initialized) {
     gst_mixer_signals[RECORD_TOGGLED] =
-      g_signal_new ("record-toggled",
-		    GST_TYPE_MIXER, G_SIGNAL_RUN_LAST,
-		    G_STRUCT_OFFSET (GstMixerClass, record_toggled),
-		    NULL, NULL,
-		    gst_mixer_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 1,
-		    GST_TYPE_MIXER_TRACK, G_TYPE_BOOLEAN);
+        g_signal_new ("record-toggled",
+        GST_TYPE_MIXER, G_SIGNAL_RUN_LAST,
+        G_STRUCT_OFFSET (GstMixerClass, record_toggled),
+        NULL, NULL,
+        gst_mixer_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2,
+        GST_TYPE_MIXER_TRACK, G_TYPE_BOOLEAN);
     gst_mixer_signals[MUTE_TOGGLED] =
-      g_signal_new ("mute-toggled",
-		    GST_TYPE_MIXER, G_SIGNAL_RUN_LAST,
-		    G_STRUCT_OFFSET (GstMixerClass, mute_toggled),
-		    NULL, NULL,
-		    gst_mixer_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 1,
-		    GST_TYPE_MIXER_TRACK, G_TYPE_BOOLEAN);
+        g_signal_new ("mute-toggled",
+        GST_TYPE_MIXER, G_SIGNAL_RUN_LAST,
+        G_STRUCT_OFFSET (GstMixerClass, mute_toggled),
+        NULL, NULL,
+        gst_mixer_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2,
+        GST_TYPE_MIXER_TRACK, G_TYPE_BOOLEAN);
     gst_mixer_signals[VOLUME_CHANGED] =
-      g_signal_new ("volume-changed",
-		    GST_TYPE_MIXER, G_SIGNAL_RUN_LAST,
-		    G_STRUCT_OFFSET (GstMixerClass, volume_changed),
-		    NULL, NULL,
-		    gst_mixer_marshal_VOID__OBJECT_POINTER, G_TYPE_NONE, 1,
-		    GST_TYPE_MIXER_TRACK, G_TYPE_POINTER);
-      
+        g_signal_new ("volume-changed",
+        GST_TYPE_MIXER, G_SIGNAL_RUN_LAST,
+        G_STRUCT_OFFSET (GstMixerClass, volume_changed),
+        NULL, NULL,
+        gst_mixer_marshal_VOID__OBJECT_POINTER, G_TYPE_NONE, 2,
+        GST_TYPE_MIXER_TRACK, G_TYPE_POINTER);
+
     initialized = TRUE;
   }
 
   klass->mixer_type = GST_MIXER_SOFTWARE;
-  
+
   /* default virtual functions */
   klass->list_tracks = NULL;
   klass->set_volume = NULL;
@@ -119,7 +119,7 @@ gst_mixer_class_init (GstMixerClass *klass)
  */
 
 const GList *
-gst_mixer_list_tracks (GstMixer *mixer)
+gst_mixer_list_tracks (GstMixer * mixer)
 {
   GstMixerClass *klass = GST_MIXER_GET_CLASS (mixer);
 
@@ -146,9 +146,7 @@ gst_mixer_list_tracks (GstMixer *mixer)
  */
 
 void
-gst_mixer_set_volume (GstMixer      *mixer,
-		      GstMixerTrack *track,
-		      gint          *volumes)
+gst_mixer_set_volume (GstMixer * mixer, GstMixerTrack * track, gint * volumes)
 {
   GstMixerClass *klass = GST_MIXER_GET_CLASS (mixer);
 
@@ -169,9 +167,7 @@ gst_mixer_set_volume (GstMixer      *mixer,
  */
 
 void
-gst_mixer_get_volume (GstMixer      *mixer,
-		      GstMixerTrack *track,
-		      gint          *volumes)
+gst_mixer_get_volume (GstMixer * mixer, GstMixerTrack * track, gint * volumes)
 {
   GstMixerClass *klass = GST_MIXER_GET_CLASS (mixer);
 
@@ -198,9 +194,7 @@ gst_mixer_get_volume (GstMixer      *mixer,
  */
 
 void
-gst_mixer_set_mute (GstMixer      *mixer,
-		    GstMixerTrack *track,
-		    gboolean       mute)
+gst_mixer_set_mute (GstMixer * mixer, GstMixerTrack * track, gboolean mute)
 {
   GstMixerClass *klass = GST_MIXER_GET_CLASS (mixer);
 
@@ -223,9 +217,7 @@ gst_mixer_set_mute (GstMixer      *mixer,
  */
 
 void
-gst_mixer_set_record (GstMixer      *mixer,
-		      GstMixerTrack *track,
-		      gboolean       record)
+gst_mixer_set_record (GstMixer * mixer, GstMixerTrack * track, gboolean record)
 {
   GstMixerClass *klass = GST_MIXER_GET_CLASS (mixer);
 
@@ -235,43 +227,30 @@ gst_mixer_set_record (GstMixer      *mixer,
 }
 
 void
-gst_mixer_mute_toggled (GstMixer      *mixer,
-			GstMixerTrack *track,
-			gboolean       mute)
+gst_mixer_mute_toggled (GstMixer * mixer, GstMixerTrack * track, gboolean mute)
 {
   g_signal_emit (G_OBJECT (mixer),
-		 gst_mixer_signals[MUTE_TOGGLED], 0,
-		 track, mute);
+      gst_mixer_signals[MUTE_TOGGLED], 0, track, mute);
 
-  g_signal_emit_by_name (G_OBJECT (track),
-			 "mute_toggled",
-			 mute);
+  g_signal_emit_by_name (G_OBJECT (track), "mute_toggled", mute);
 }
 
 void
-gst_mixer_record_toggled (GstMixer      *mixer,
-			  GstMixerTrack *track,
-			  gboolean       record)
+gst_mixer_record_toggled (GstMixer * mixer,
+    GstMixerTrack * track, gboolean record)
 {
   g_signal_emit (G_OBJECT (mixer),
-		 gst_mixer_signals[RECORD_TOGGLED], 0,
-		 track, record);
+      gst_mixer_signals[RECORD_TOGGLED], 0, track, record);
 
-  g_signal_emit_by_name (G_OBJECT (track),
-			 "record_toggled",
-			 record);
+  g_signal_emit_by_name (G_OBJECT (track), "record_toggled", record);
 }
 
 void
-gst_mixer_volume_changed (GstMixer      *mixer,
-			  GstMixerTrack *track,
-			  gint          *volumes)
+gst_mixer_volume_changed (GstMixer * mixer,
+    GstMixerTrack * track, gint * volumes)
 {
   g_signal_emit (G_OBJECT (mixer),
-		 gst_mixer_signals[VOLUME_CHANGED], 0,
-		 track, volumes);
+      gst_mixer_signals[VOLUME_CHANGED], 0, track, volumes);
 
-  g_signal_emit_by_name (G_OBJECT (track),
-			 "volume_changed",
-			 volumes);
+  g_signal_emit_by_name (G_OBJECT (track), "volume_changed", volumes);
 }
