@@ -38,6 +38,7 @@
 
 #include <gst/gst.h>
 #include <string.h>
+#include "plugin.h"
 
 GST_DEBUG_CATEGORY_STATIC (audio_convert_debug);
 #define GST_CAT_DEFAULT (audio_convert_debug)
@@ -100,7 +101,6 @@ static GstElementDetails audio_convert_details = {
 };
 
 /* type functions */
-static GType gst_audio_convert_get_type (void);
 static void gst_audio_convert_base_init (gpointer g_class);
 static void gst_audio_convert_class_init (GstAudioConvertClass * klass);
 static void gst_audio_convert_init (GstAudioConvert * audio_convert);
@@ -109,6 +109,7 @@ static void gst_audio_convert_init (GstAudioConvert * audio_convert);
 static void gst_audio_convert_chain (GstPad * pad, GstData * _data);
 static GstPadLinkReturn gst_audio_convert_link (GstPad * pad,
     const GstCaps * caps);
+static GstCaps *gst_audio_convert_fixate (GstPad * pad, const GstCaps * caps);
 static GstCaps *gst_audio_convert_getcaps (GstPad * pad);
 static GstElementStateReturn gst_audio_convert_change_state (GstElement *
     element);
@@ -202,6 +203,7 @@ gst_audio_convert_init (GstAudioConvert * this)
       (&gst_audio_convert_sink_template), "sink");
   gst_pad_set_getcaps_function (this->sink, gst_audio_convert_getcaps);
   gst_pad_set_link_function (this->sink, gst_audio_convert_link);
+  gst_pad_set_fixate_function (this->sink, gst_audio_convert_fixate);
   gst_element_add_pad (GST_ELEMENT (this), this->sink);
 
   /* srcpad */
@@ -210,6 +212,7 @@ gst_audio_convert_init (GstAudioConvert * this)
       (&gst_audio_convert_src_template), "src");
   gst_pad_set_getcaps_function (this->src, gst_audio_convert_getcaps);
   gst_pad_set_link_function (this->src, gst_audio_convert_link);
+  gst_pad_set_fixate_function (this->src, gst_audio_convert_fixate);
   gst_element_add_pad (GST_ELEMENT (this), this->src);
 
   gst_pad_set_chain_function (this->sink, gst_audio_convert_chain);
@@ -239,7 +242,8 @@ gst_audio_convert_chain (GstPad * pad, GstData * data)
 
   if (!gst_pad_is_negotiated (this->sink)) {
     GST_ELEMENT_ERROR (this, CORE, NEGOTIATION, (NULL),
-        ("Sink pad not negotiated before chain function"));
+        ("Sink pad (connected to %s:%s) not negotiated before chain function",
+         GST_DEBUG_PAD_NAME (gst_pad_get_peer (this->sink))));
     return;
   }
   if (!gst_pad_is_negotiated (this->src)) {
@@ -298,7 +302,12 @@ gst_audio_convert_getcaps (GstPad * pad)
     structure = gst_structure_copy (structure);
     if (strcmp (gst_structure_get_name (structure), "audio/x-raw-int") == 0) {
       gst_structure_set_name (structure, "audio/x-raw-float");
-      gst_structure_set (structure, "buffer-frames", G_TYPE_INT, 0, NULL);
+      if (pad == this->sink) {
+        gst_structure_set (structure, "buffer-frames", GST_TYPE_INT_RANGE, 0,
+            G_MAXINT, NULL);
+      } else {
+        gst_structure_set (structure, "buffer-frames", G_TYPE_INT, 0, NULL);
+      }
     } else {
       gst_structure_set_name (structure, "audio/x-raw-int");
       gst_structure_remove_field (structure, "buffer-frames");
@@ -386,6 +395,12 @@ gst_audio_convert_link (GstPad * pad, const GstCaps * caps)
       }
     }
   }
+  if (this->sink == pad) {
+    this->sinkcaps = ac_caps;
+  } else {
+    this->srccaps = ac_caps;
+  }
+  GST_LOG_OBJECT (this, "trying to set caps to %" GST_PTR_FORMAT, othercaps);
   ret = gst_pad_try_set_caps_nonfixed (otherpad, othercaps);
   gst_caps_free (othercaps);
   if (ret < GST_PAD_LINK_OK)
@@ -406,11 +421,75 @@ gst_audio_convert_link (GstPad * pad, const GstCaps * caps)
     this->sinkcaps = other_ac_caps;
   }
 
-  GST_DEBUG ("negotiated pad to %" GST_PTR_FORMAT, caps);
-  GST_DEBUG ("negotiated otherpad to %" GST_PTR_FORMAT, othercaps);
+  GST_DEBUG_OBJECT (this, "negotiated pad to %" GST_PTR_FORMAT, caps);
   return GST_PAD_LINK_OK;
 }
 
+gboolean
+_fixate_caps_to_int (GstCaps ** caps, const gchar * field, gint value)
+{
+  GstCaps *try, *intersection;
+  gboolean ret = FALSE;
+  guint i;
+
+  try = gst_caps_new_simple ("audio/x-raw-int", field, GST_TYPE_INT_RANGE,
+      G_MININT, value - 1, NULL);
+  gst_caps_append (try, gst_caps_new_simple ("audio/x-raw-float", field,
+          GST_TYPE_INT_RANGE, G_MININT, value - 1, NULL));
+  intersection = gst_caps_intersect (*caps, try);
+  if (!gst_caps_is_empty (intersection)) {
+    gst_caps_free (try);
+    try = gst_caps_new_simple ("audio/x-raw-int", field, GST_TYPE_INT_RANGE,
+        value, G_MAXINT, NULL);
+    gst_caps_append (try, gst_caps_new_simple ("audio/x-raw-float", field,
+            GST_TYPE_INT_RANGE, value, G_MAXINT, NULL));
+    gst_caps_free (intersection);
+    intersection = gst_caps_intersect (*caps, try);
+    if (!gst_caps_is_empty (intersection)) {
+      gst_caps_free (*caps);
+      *caps = intersection;
+      ret = TRUE;
+    } else {
+      gst_caps_free (intersection);
+    }
+  }
+  gst_caps_free (try);
+  for (i = 0; i < gst_caps_get_size (*caps); i++) {
+    GstStructure *structure = gst_caps_get_structure (*caps, i);
+
+    if (gst_structure_has_field (structure, field))
+      ret |=
+          gst_caps_structure_fixate_field_nearest_int (structure, field, value);
+  }
+  return ret;
+}
+
+static GstCaps *
+gst_audio_convert_fixate (GstPad * pad, const GstCaps * caps)
+{
+  GstAudioConvert *this =
+      GST_AUDIO_CONVERT (gst_object_get_parent (GST_OBJECT (pad)));
+  GstPad *otherpad = (pad == this->sink ? this->src : this->sink);
+  GstAudioConvertCaps ac_caps =
+      (pad == this->sink ? this->srccaps : this->sinkcaps);
+  GstCaps *copy;
+
+  /* only fixate when we're proxying, so we don't fixate to some crap the other side doesn't want */
+  if (!GST_PAD_IS_NEGOTIATING (otherpad))
+    return NULL;
+
+  copy = gst_caps_copy (caps);
+  if (_fixate_caps_to_int (&copy, "channels", ac_caps.channels))
+    return copy;
+  if (_fixate_caps_to_int (&copy, "width", ac_caps.is_int ? ac_caps.width : 16))
+    return copy;
+  if (_fixate_caps_to_int (&copy, "depth", ac_caps.is_int ? ac_caps.depth : 16))
+    return copy;
+
+  gst_caps_free (copy);
+  return NULL;
+}
+
 static GstElementStateReturn
 gst_audio_convert_change_state (GstElement * element)
 {
@@ -555,7 +634,6 @@ gst_audio_convert_buffer_to_default_format (GstAudioConvert * this,
 
     in = (gfloat *) GST_BUFFER_DATA (buf);
     out = (gint32 *) GST_BUFFER_DATA (ret);
-    /* increment `in' via the for, cause CLAMP duplicates the first arg */
     for (i = buf->size / sizeof (float); i > 0; i--) {
       *in *= 2147483647.0f + .5;
       *out = (gint32) CLAMP ((gint64) * in, -2147483648ll, 2147483647ll);
@@ -701,21 +779,3 @@ gst_audio_convert_channels (GstAudioConvert * this, GstBuffer * buf)
   gst_buffer_unref (buf);
   return ret;
 }
-
-/*** PLUGIN DETAILS ***********************************************************/
-
-static gboolean
-plugin_init (GstPlugin * plugin)
-{
-  if (!gst_element_register (plugin, "audioconvert", GST_RANK_PRIMARY,
-          GST_TYPE_AUDIO_CONVERT))
-    return FALSE;
-
-  return TRUE;
-}
-
-GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
-    GST_VERSION_MINOR,
-    "gstaudioconvert",
-    "Convert audio to different formats",
-    plugin_init, VERSION, "LGPL", GST_PACKAGE, GST_ORIGIN)
