@@ -187,6 +187,7 @@ gst_avi_demux_reset (GstAviDemux * avi)
   for (i = 0; i < avi->num_streams; i++) {
     g_free (avi->stream[i].strh);
     gst_element_remove_pad (GST_ELEMENT (avi), avi->stream[i].pad);
+    gst_caps_free (avi->stream[i].caps);
   }
   memset (&avi->stream, 0, sizeof (avi->stream));
 
@@ -751,7 +752,8 @@ gst_avi_demux_add_stream (GstAviDemux * avi)
     gst_riff_strf_vids *vids;
     gst_riff_strf_auds *auds;
     gst_riff_strf_iavs *iavs;
-  } strf;
+  }
+  strf;
 
   /* the stream starts with a 'strh' header */
   if (!(tag = gst_riff_peek_tag (riff, NULL)))
@@ -1064,6 +1066,9 @@ gst_avi_demux_stream_index (GstAviDemux * avi)
     entry.size = GUINT32_FROM_LE (_entry->size);
     target = &avi->index_entries[i];
 
+    if (entry.id == GST_RIFF_rec)
+      continue;
+
     stream_nr = CHUNKID_TO_STREAMNR (entry.id);
     if (stream_nr >= avi->num_streams || stream_nr < 0) {
       g_warning ("Index entry %d has invalid stream nr %d", i, stream_nr);
@@ -1387,6 +1392,25 @@ gst_avi_demux_stream_data (GstAviDemux * avi)
   /* And then, we get the data */
   if (!(tag = gst_riff_peek_tag (riff, NULL)))
     return FALSE;
+
+  /* Support for rec-list files */
+  switch (tag) {
+    case GST_RIFF_TAG_LIST:
+      if (!(tag = gst_riff_peek_list (riff)))
+        return FALSE;
+      if (tag == GST_RIFF_rec) {
+        /* Simply skip the list */
+        if (!gst_riff_read_list (riff, &tag))
+          return FALSE;
+        if (!(tag = gst_riff_peek_tag (riff, NULL)))
+          return FALSE;
+      }
+      break;
+
+    case GST_RIFF_TAG_JUNK:
+      return gst_riff_read_skip (riff);
+  }
+
   stream_nr = CHUNKID_TO_STREAMNR (tag);
   if (stream_nr < 0 || stream_nr >= avi->num_streams) {
     /* recoverable */
