@@ -20,7 +20,7 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- */ 
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -28,14 +28,14 @@
 #include <math.h>
 #include <string.h>
 #include <gst/gst.h>
-#include "gsteffectv.h"
+#include <gstvideofilter.h>
 
 #define GST_TYPE_SHAGADELICTV \
   (gst_shagadelictv_get_type())
 #define GST_SHAGADELICTV(obj) \
   (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_SHAGADELICTV,GstShagadelicTV))
 #define GST_SHAGADELICTV_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_ULAW,GstShagadelicTV))
+  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_SHAGADELICTV,GstShagadelicTVClass))
 #define GST_IS_SHAGADELICTV(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_SHAGADELICTV))
 #define GST_IS_SHAGADELICTV_CLASS(obj) \
@@ -46,9 +46,7 @@ typedef struct _GstShagadelicTVClass GstShagadelicTVClass;
 
 struct _GstShagadelicTV
 {
-  GstElement element;
-
-  GstPad *sinkpad, *srcpad;
+  GstVideofilter videofilter;
 
   gint width, height;
   gint stat;
@@ -63,18 +61,9 @@ struct _GstShagadelicTV
 
 struct _GstShagadelicTVClass
 {
-  GstElementClass parent_class;
+  GstVideofilterClass parent_class;
 };
 
-/* elementfactory information */
-static GstElementDetails gst_shagadelictv_details = GST_ELEMENT_DETAILS (
-  "ShagadelicTV",
-  "Filter/Effect/Video",
-  "Oh behave, ShagedelicTV makes images shagadelic!",
-  "Wim Taymans <wim.taymans@chello.be>"
-);
-
-
 /* Filter signals and args */
 enum
 {
@@ -87,29 +76,30 @@ enum
   ARG_0,
 };
 
-static void	gst_shagadelictv_base_init	(gpointer g_class);
-static void 	gst_shagadelictv_class_init 	(GstShagadelicTVClass * klass);
-static void 	gst_shagadelictv_init 		(GstShagadelicTV * filter);
+static void gst_shagadelictv_base_init (gpointer g_class);
+static void gst_shagadelictv_class_init (gpointer g_class, gpointer class_data);
+static void gst_shagadelictv_init (GTypeInstance * instance, gpointer g_class);
 
-static void 	gst_shagadelic_initialize 	(GstShagadelicTV *filter);
+static void gst_shagadelic_initialize (GstShagadelicTV * filter);
 
-static void 	gst_shagadelictv_set_property 	(GObject * object, guint prop_id,
-					  	 const GValue * value, GParamSpec * pspec);
-static void 	gst_shagadelictv_get_property 	(GObject * object, guint prop_id,
-					  	 GValue * value, GParamSpec * pspec);
+static void gst_shagadelictv_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+static void gst_shagadelictv_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
+static void gst_shagadelictv_setup (GstVideofilter * videofilter);
+static void gst_shagadelictv_rgb32 (GstVideofilter * videofilter, void *d,
+    void *s);
 
-static void 	gst_shagadelictv_chain 		(GstPad * pad, GstData *_data);
-
-static GstElementClass *parent_class = NULL;
 /*static guint gst_shagadelictv_signals[LAST_SIGNAL] = { 0 }; */
 
-GType gst_shagadelictv_get_type (void)
+GType
+gst_shagadelictv_get_type (void)
 {
   static GType shagadelictv_type = 0;
 
   if (!shagadelictv_type) {
     static const GTypeInfo shagadelictv_info = {
-      sizeof (GstShagadelicTVClass), 
+      sizeof (GstShagadelicTVClass),
       gst_shagadelictv_base_init,
       NULL,
       (GClassInitFunc) gst_shagadelictv_class_init,
@@ -120,50 +110,79 @@ GType gst_shagadelictv_get_type (void)
       (GInstanceInitFunc) gst_shagadelictv_init,
     };
 
-    shagadelictv_type = g_type_register_static (GST_TYPE_ELEMENT, "GstShagadelicTV", &shagadelictv_info, 0);
+    shagadelictv_type =
+        g_type_register_static (GST_TYPE_VIDEOFILTER, "GstShagadelicTV",
+        &shagadelictv_info, 0);
   }
   return shagadelictv_type;
 }
 
+static GstVideofilterFormat gst_shagadelictv_formats[] = {
+  {"RGB ", 32, gst_shagadelictv_rgb32, 24, G_BIG_ENDIAN, 0x0000ff00, 0x00ff0000,
+      0xff000000}
+};
+
 static void
 gst_shagadelictv_base_init (gpointer g_class)
 {
+  /* elementfactory information */
+  static GstElementDetails gst_shagadelictv_details =
+      GST_ELEMENT_DETAILS ("ShagadelicTV",
+      "Filter/Effect/Video",
+      "Oh behave, ShagedelicTV makes images shagadelic!",
+      "Wim Taymans <wim.taymans@chello.be>");
+
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
+  GstVideofilterClass *videofilter_class = GST_VIDEOFILTER_CLASS (g_class);
+  int i;
 
-  gst_element_class_add_pad_template (element_class, gst_effectv_src_factory ());
-  gst_element_class_add_pad_template (element_class, gst_effectv_sink_factory ());
- 
   gst_element_class_set_details (element_class, &gst_shagadelictv_details);
+
+  for (i = 0; i < G_N_ELEMENTS (gst_shagadelictv_formats); i++) {
+    gst_videofilter_class_add_format (videofilter_class,
+        gst_shagadelictv_formats + i);
+  }
+
+  gst_videofilter_class_add_pad_templates (GST_VIDEOFILTER_CLASS (g_class));
 }
 
 static void
-gst_shagadelictv_class_init (GstShagadelicTVClass * klass)
+gst_shagadelictv_class_init (gpointer g_class, gpointer class_data)
 {
   GObjectClass *gobject_class;
-  GstElementClass *gstelement_class;
+  GstVideofilterClass *videofilter_class;
 
-  gobject_class = (GObjectClass *) klass;
-  gstelement_class = (GstElementClass *) klass;
-
-  parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
+  gobject_class = G_OBJECT_CLASS (g_class);
+  videofilter_class = GST_VIDEOFILTER_CLASS (g_class);
 
   gobject_class->set_property = gst_shagadelictv_set_property;
   gobject_class->get_property = gst_shagadelictv_get_property;
+
+  videofilter_class->setup = gst_shagadelictv_setup;
 }
 
-static GstPadLinkReturn
-gst_shagadelictv_sinkconnect (GstPad * pad, GstCaps * caps)
+static void
+gst_shagadelictv_init (GTypeInstance * instance, gpointer g_class)
+{
+  GstShagadelicTV *filter = GST_SHAGADELICTV (instance);
+
+  filter->ripple = NULL;
+  filter->spiral = NULL;
+}
+
+static void
+gst_shagadelictv_setup (GstVideofilter * videofilter)
 {
   GstShagadelicTV *filter;
-  gint area;
+  int width = gst_videofilter_get_input_width (videofilter);
+  int height = gst_videofilter_get_input_height (videofilter);
+  int area;
 
-  filter = GST_SHAGADELICTV (gst_pad_get_parent (pad));
+  g_return_if_fail (GST_IS_SHAGADELICTV (videofilter));
+  filter = GST_SHAGADELICTV (videofilter);
 
-  if (!GST_CAPS_IS_FIXED (caps))
-    return GST_PAD_LINK_DELAYED;
-
-  gst_caps_get_int (caps, "width", &filter->width);
-  gst_caps_get_int (caps, "height", &filter->height);
+  filter->width = width;
+  filter->height = height;
 
   area = filter->width * filter->height;
 
@@ -174,37 +193,21 @@ gst_shagadelictv_sinkconnect (GstPad * pad, GstCaps * caps)
   filter->spiral = (gchar *) g_malloc (area);
 
   gst_shagadelic_initialize (filter);
-
-  return gst_pad_try_set_caps (filter->srcpad, gst_caps_ref (caps));
-}
-
-static void
-gst_shagadelictv_init (GstShagadelicTV * filter)
-{
-  filter->sinkpad = gst_pad_new_from_template (gst_effectv_sink_factory (), "sink");
-  gst_pad_set_chain_function (filter->sinkpad, gst_shagadelictv_chain);
-  gst_pad_set_link_function (filter->sinkpad, gst_shagadelictv_sinkconnect);
-  gst_element_add_pad (GST_ELEMENT (filter), filter->sinkpad);
-
-  filter->srcpad = gst_pad_new_from_template (gst_effectv_src_factory (), "src");
-  gst_element_add_pad (GST_ELEMENT (filter), filter->srcpad);
-
-  filter->ripple = NULL;
-  filter->spiral = NULL;
 }
 
 static unsigned int
 fastrand (void)
-{   
+{
   static unsigned int fastrand_val;
 
   return (fastrand_val = fastrand_val * 1103515245 + 12345);
 }
 
 static void
-gst_shagadelic_initialize (GstShagadelicTV *filter)
+gst_shagadelic_initialize (GstShagadelicTV * filter)
 {
   int i, x, y;
+
 #ifdef PS2
   float xx, yy;
 #else
@@ -212,32 +215,35 @@ gst_shagadelic_initialize (GstShagadelicTV *filter)
 #endif
 
   i = 0;
-  for(y = 0; y < filter->height * 2; y++) {
+  for (y = 0; y < filter->height * 2; y++) {
     yy = y - filter->height;
     yy *= yy;
 
     for (x = 0; x < filter->width * 2; x++) {
       xx = x - filter->width;
 #ifdef PS2
-      filter->ripple[i++] = ((unsigned int)(sqrtf(xx*xx+yy)*8))&255;
+      filter->ripple[i++] = ((unsigned int) (sqrtf (xx * xx + yy) * 8)) & 255;
 #else
-      filter->ripple[i++] = ((unsigned int)(sqrt(xx*xx+yy)*8))&255;
+      filter->ripple[i++] = ((unsigned int) (sqrt (xx * xx + yy) * 8)) & 255;
 #endif
     }
   }
 
   i = 0;
   for (y = 0; y < filter->height; y++) {
-    yy = y - filter->height/2;
-    
+    yy = y - filter->height / 2;
+
     for (x = 0; x < filter->width; x++) {
-      xx = x - filter->width/2;
+      xx = x - filter->width / 2;
 #ifdef PS2
       filter->spiral[i++] = ((unsigned int)
-	((atan2f(xx, yy)/((float)M_PI)*256*9) + (sqrtf(xx*xx+yy*yy)*5)))&255;
+          ((atan2f (xx,
+                      yy) / ((float) M_PI) * 256 * 9) + (sqrtf (xx * xx +
+                      yy * yy) * 5))) & 255;
 #else
       filter->spiral[i++] = ((unsigned int)
-	((atan2(xx, yy)/M_PI*256*9) + (sqrt(xx*xx+yy*yy)*5)))&255;
+          ((atan2 (xx, yy) / M_PI * 256 * 9) + (sqrt (xx * xx +
+                      yy * yy) * 5))) & 255;
 #endif
 /* Here is another Swinger!
  * ((atan2(xx, yy)/M_PI*256) + (sqrt(xx*xx+yy*yy)*10))&255;
@@ -255,30 +261,20 @@ gst_shagadelic_initialize (GstShagadelicTV *filter)
   filter->phase = 0;
 }
 
-int shagadelicDraw()
-{
-	return 0;
-}
 static void
-gst_shagadelictv_chain (GstPad * pad, GstData *_data)
+gst_shagadelictv_rgb32 (GstVideofilter * videofilter, void *d, void *s)
 {
-  GstBuffer *buf = GST_BUFFER (_data);
   GstShagadelicTV *filter;
   guint32 *src, *dest;
-  GstBuffer *outbuf;
   gint x, y;
   guint32 v;
   guchar r, g, b;
   gint width, height;
 
-  filter = GST_SHAGADELICTV (gst_pad_get_parent (pad));
+  filter = GST_SHAGADELICTV (videofilter);
 
-  src = (guint32 *) GST_BUFFER_DATA (buf);
-
-  outbuf = gst_buffer_new ();
-  GST_BUFFER_SIZE (outbuf) = (filter->width * filter->height * 4);
-  dest = (guint32 *) GST_BUFFER_DATA (outbuf) = g_malloc (GST_BUFFER_SIZE (outbuf));
-  GST_BUFFER_TIMESTAMP (outbuf) = GST_BUFFER_TIMESTAMP (buf);
+  src = (guint32 *) s;
+  dest = (guint32 *) d;
 
   width = filter->width;
   height = filter->height;
@@ -292,30 +288,33 @@ gst_shagadelictv_chain (GstPad * pad, GstData *_data)
  * v = *src++;
  * *dest++ = v & ((r<<16)|(g<<8)|b);
  */
-      r = (gchar) (filter->ripple[(filter->ry + y) * width * 2 + filter->rx + x] + filter->phase * 2) >> 7;
+      r = (gchar) (filter->ripple[(filter->ry + y) * width * 2 + filter->rx +
+              x] + filter->phase * 2) >> 7;
       g = (gchar) (filter->spiral[y * width + x] + filter->phase * 3) >> 7;
-      b = (gchar) (filter->ripple[(filter->by + y) * width * 2 + filter->bx + x] - filter->phase) >> 7;
+      b = (gchar) (filter->ripple[(filter->by + y) * width * 2 + filter->bx +
+              x] - filter->phase) >> 7;
       *dest++ = v & ((r << 16) | (g << 8) | b);
     }
   }
 
   filter->phase -= 8;
-  if ((filter->rx + filter->rvx) < 0 || (filter->rx + filter->rvx) >= width)  filter->rvx =- filter->rvx;
-  if ((filter->ry + filter->rvy) < 0 || (filter->ry + filter->rvy) >= height) filter->rvy =- filter->rvy;
-  if ((filter->bx + filter->bvx) < 0 || (filter->bx + filter->bvx) >= width)  filter->bvx =- filter->bvx;
-  if ((filter->by + filter->bvy) < 0 || (filter->by + filter->bvy) >= height) filter->bvy =- filter->bvy;
+  if ((filter->rx + filter->rvx) < 0 || (filter->rx + filter->rvx) >= width)
+    filter->rvx = -filter->rvx;
+  if ((filter->ry + filter->rvy) < 0 || (filter->ry + filter->rvy) >= height)
+    filter->rvy = -filter->rvy;
+  if ((filter->bx + filter->bvx) < 0 || (filter->bx + filter->bvx) >= width)
+    filter->bvx = -filter->bvx;
+  if ((filter->by + filter->bvy) < 0 || (filter->by + filter->bvy) >= height)
+    filter->bvy = -filter->bvy;
   filter->rx += filter->rvx;
   filter->ry += filter->rvy;
   filter->bx += filter->bvx;
   filter->by += filter->bvy;
-
-  gst_buffer_unref (buf);
-
-  gst_pad_push (filter->srcpad, GST_DATA (outbuf));
 }
 
 static void
-gst_shagadelictv_set_property (GObject * object, guint prop_id, const GValue * value, GParamSpec * pspec)
+gst_shagadelictv_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   GstShagadelicTV *filter;
 
@@ -331,7 +330,8 @@ gst_shagadelictv_set_property (GObject * object, guint prop_id, const GValue * v
 }
 
 static void
-gst_shagadelictv_get_property (GObject * object, guint prop_id, GValue * value, GParamSpec * pspec)
+gst_shagadelictv_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstShagadelicTV *filter;
 
