@@ -42,7 +42,8 @@
 typedef struct _Deinterleave Deinterleave;
 typedef struct _DeinterleaveClass DeinterleaveClass;
 
-struct _Deinterleave {
+struct _Deinterleave
+{
   GstElement element;
 
   GstPad *sinkpad;
@@ -52,11 +53,12 @@ struct _Deinterleave {
 
   GstBuffer **out_buffers;
   gpointer *out_data;
-	
+
   GList *srcpads;
 };
 
-struct _DeinterleaveClass {
+struct _DeinterleaveClass
+{
   GstElementClass parent_class;
 };
 
@@ -64,74 +66,64 @@ static GstElementDetails details = {
   "Audio deinterleaver",
   "Filter/Converter/Audio",
   "Splits one interleaved multichannel audio stream into many mono audio streams",
-  "Andy Wingo <wingo at pobox.com>, "
-  "Iain <iain@prettypeople.org>"
+  "Andy Wingo <wingo at pobox.com>, " "Iain <iain@prettypeople.org>"
 };
 
 static GstStaticPadTemplate deinterleave_sink_template =
-GST_STATIC_PAD_TEMPLATE (
-  "sink",
-  GST_PAD_SINK,
-  GST_PAD_ALWAYS,
-  GST_STATIC_CAPS (
-    "audio/x-raw-int, "
-    "endianness = (int) BYTE_ORDER, "
-    "signed = (boolean) TRUE, "
-    "width = (int) 16, "
-    "depth = (int) 16, "
-    "rate = (int) [ 1, MAX ], "
-    "channels = (int) [ 1, MAX ];"
-
-    "audio/x-raw-float, "
-    "rate = (int) [ 1, MAX ], "
-    "channels = (int) [ 1, MAX ], "
-    "endianness = (int) BYTE_ORDER, "
-    "width = (int) 32, "
-    "buffer-frames = (int) [ 0, MAX ]"
-  )
-);
+    GST_STATIC_PAD_TEMPLATE ("sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("audio/x-raw-int, "
+        "endianness = (int) BYTE_ORDER, "
+        "signed = (boolean) TRUE, "
+        "width = (int) 16, "
+        "depth = (int) 16, "
+        "rate = (int) [ 1, MAX ], "
+        "channels = (int) [ 1, MAX ];"
+        "audio/x-raw-float, "
+        "rate = (int) [ 1, MAX ], "
+        "channels = (int) [ 1, MAX ], "
+        "endianness = (int) BYTE_ORDER, "
+        "width = (int) 32, " "buffer-frames = (int) [ 0, MAX ]")
+    );
 
 static GstStaticPadTemplate deinterleave_src_template =
-GST_STATIC_PAD_TEMPLATE (
-  "src_%d",
-  GST_PAD_SRC,
-  GST_PAD_SOMETIMES,
-  GST_STATIC_CAPS (
-    "audio/x-raw-int, "
-    "endianness = (int) BYTE_ORDER, "
-    "signed = (boolean) TRUE, "
-    "width = (int) 16, "
-    "depth = (int) 16, "
-    "rate = (int) [ 4000, 96000 ], "
-    "channels = (int) 1;"
+    GST_STATIC_PAD_TEMPLATE ("src_%d",
+    GST_PAD_SRC,
+    GST_PAD_SOMETIMES,
+    GST_STATIC_CAPS ("audio/x-raw-int, "
+        "endianness = (int) BYTE_ORDER, "
+        "signed = (boolean) TRUE, "
+        "width = (int) 16, "
+        "depth = (int) 16, "
+        "rate = (int) [ 4000, 96000 ], "
+        "channels = (int) 1;"
+        "audio/x-raw-float, "
+        "rate = (int) [ 1, MAX ], "
+        "channels = (int) 1, "
+        "endianness = (int) BYTE_ORDER, "
+        "width = (int) 32, " "buffer-frames = (int) [ 0, MAX ]")
+    );
 
-    "audio/x-raw-float, "
-    "rate = (int) [ 1, MAX ], "
-    "channels = (int) 1, "
-    "endianness = (int) BYTE_ORDER, "
-    "width = (int) 32, "
-    "buffer-frames = (int) [ 0, MAX ]"
-  )
-);
-
-static void	deinterleave_class_init		(DeinterleaveClass *klass);
-static void	deinterleave_base_init		(DeinterleaveClass *klass);
-static void	deinterleave_init		(Deinterleave *deinterleave);
-static GstCaps*	deinterleave_sink_getcaps	(GstPad *pad);
-static GstCaps*	deinterleave_src_getcaps	(GstPad *pad);
-static GstPadLinkReturn deinterleave_sink_link	(GstPad *pad,
-                                                 const GstCaps *caps);
-static GstElementStateReturn deinterleave_change_state (GstElement *element);
-static void	deinterleave_chain		(GstPad *pad, GstData *_data);
-static void inline do_int_deinterleave		(gint16 *in_data, int channels,
-                                                 gint16 **out_data, guint numframes);
-static void inline do_float_deinterleave	(gfloat *in_data, int channels,
-                                                 gfloat **out_data, guint numframes);
+static void deinterleave_class_init (DeinterleaveClass * klass);
+static void deinterleave_base_init (DeinterleaveClass * klass);
+static void deinterleave_init (Deinterleave * deinterleave);
+static GstCaps *deinterleave_sink_getcaps (GstPad * pad);
+static GstCaps *deinterleave_src_getcaps (GstPad * pad);
+static GstPadLinkReturn deinterleave_sink_link (GstPad * pad,
+    const GstCaps * caps);
+static GstElementStateReturn deinterleave_change_state (GstElement * element);
+static void deinterleave_chain (GstPad * pad, GstData * _data);
+static void inline do_int_deinterleave (gint16 * in_data, int channels,
+    gint16 ** out_data, guint numframes);
+static void inline do_float_deinterleave (gfloat * in_data, int channels,
+    gfloat ** out_data, guint numframes);
 
 static GstElementClass *parent_class = NULL;
 
 GType
-gstplugin_deinterleave_get_type (void) {
+gstplugin_deinterleave_get_type (void)
+{
   static GType type = 0;
 
   if (type == 0) {
@@ -143,39 +135,39 @@ gstplugin_deinterleave_get_type (void) {
     };
 
     type = g_type_register_static (GST_TYPE_ELEMENT,
-                                   "GstDeinterleave", &info, 0);
+        "GstDeinterleave", &info, 0);
   }
   return type;
 }
 
 static void
-deinterleave_base_init (DeinterleaveClass *klass)
+deinterleave_base_init (DeinterleaveClass * klass)
 {
   GstElementClass *eclass = GST_ELEMENT_CLASS (klass);
 
   gst_element_class_add_pad_template
-    (eclass, gst_static_pad_template_get (&deinterleave_src_template));
+      (eclass, gst_static_pad_template_get (&deinterleave_src_template));
   gst_element_class_add_pad_template
-    (eclass, gst_static_pad_template_get (&deinterleave_sink_template));
+      (eclass, gst_static_pad_template_get (&deinterleave_sink_template));
   gst_element_class_set_details (eclass, &details);
 }
 
 static void
-deinterleave_class_init (DeinterleaveClass *klass)
+deinterleave_class_init (DeinterleaveClass * klass)
 {
-  GstElementClass *eclass = (GstElementClass*)klass;
-	
+  GstElementClass *eclass = (GstElementClass *) klass;
+
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   eclass->change_state = deinterleave_change_state;
 }
 
 static void
-deinterleave_init (Deinterleave *this)
+deinterleave_init (Deinterleave * this)
 {
   DEBUG;
-  this->sinkpad = gst_pad_new_from_template 
-    (gst_static_pad_template_get (&deinterleave_sink_template), "sink");
+  this->sinkpad = gst_pad_new_from_template
+      (gst_static_pad_template_get (&deinterleave_sink_template), "sink");
   gst_pad_set_chain_function (this->sinkpad, deinterleave_chain);
   gst_pad_set_link_function (this->sinkpad, deinterleave_sink_link);
   gst_pad_set_getcaps_function (this->sinkpad, deinterleave_sink_getcaps);
@@ -189,16 +181,16 @@ deinterleave_init (Deinterleave *this)
 }
 
 static void
-deinterleave_alloc_channels_data (Deinterleave *this)
+deinterleave_alloc_channels_data (Deinterleave * this)
 {
   if (!this->out_buffers && this->channels) {
-    this->out_buffers = g_new0 (GstBuffer*, this->channels);
+    this->out_buffers = g_new0 (GstBuffer *, this->channels);
     this->out_data = g_new0 (gpointer, this->channels);
   }
 }
 
 static void
-deinterleave_free_channels_data (Deinterleave *this)
+deinterleave_free_channels_data (Deinterleave * this)
 {
   g_free (this->out_buffers);
   g_free (this->out_data);
@@ -207,7 +199,7 @@ deinterleave_free_channels_data (Deinterleave *this)
 }
 
 static GstCaps *
-deinterleave_sink_getcaps (GstPad *pad)
+deinterleave_sink_getcaps (GstPad * pad)
 {
   Deinterleave *this;
   GList *l;
@@ -216,9 +208,9 @@ deinterleave_sink_getcaps (GstPad *pad)
   this = DEINTERLEAVE (GST_OBJECT_PARENT (pad));
 
   ret = gst_caps_copy (gst_pad_get_pad_template_caps (this->sinkpad));
-  for (l=this->srcpads; l; l=l->next) {
+  for (l = this->srcpads; l; l = l->next) {
     GstCaps *old, *allowed;
-	  
+
     allowed = gst_pad_get_allowed_caps (GST_PAD (l->data));
     old = ret;
     ret = gst_caps_intersect (old, allowed);
@@ -227,16 +219,14 @@ deinterleave_sink_getcaps (GstPad *pad)
     if (!ret)
       return gst_caps_new_empty ();
   }
-	  
+
   gst_structure_set (gst_caps_get_structure (ret, 0),
-                     "channels",
-                     GST_TYPE_INT_RANGE, 1, G_MAXINT,
-                     NULL);
+      "channels", GST_TYPE_INT_RANGE, 1, G_MAXINT, NULL);
   return ret;
 }
 
 static GstCaps *
-deinterleave_src_getcaps (GstPad *pad)
+deinterleave_src_getcaps (GstPad * pad)
 {
   Deinterleave *this;
   GstCaps *ret;
@@ -245,19 +235,18 @@ deinterleave_src_getcaps (GstPad *pad)
 
   ret = gst_pad_get_allowed_caps (this->sinkpad);
   gst_structure_set (gst_caps_get_structure (ret, 0),
-                     "channels", G_TYPE_INT, 1, NULL);
+      "channels", G_TYPE_INT, 1, NULL);
   return ret;
 }
 
 static GstPadLinkReturn
-deinterleave_sink_link (GstPad *pad, const GstCaps *caps)
+deinterleave_sink_link (GstPad * pad, const GstCaps * caps)
 {
   Deinterleave *this;
   int i, new_chans, need;
   GstCaps *srccaps;
   GList *p;
   GstStructure *structure;
-  gboolean is_int;
   GstPadLinkReturn srclink;
 
   this = DEINTERLEAVE (gst_pad_get_parent (pad));
@@ -267,9 +256,9 @@ deinterleave_sink_link (GstPad *pad, const GstCaps *caps)
   structure = gst_caps_get_structure (caps, 0);
 
   /* Get the number of channels coming in */
-  gst_structure_get_int  (structure, "channels", &new_chans);
-  is_int = (strcmp (gst_structure_get_name (structure),
-                    "audio/x-raw-int") == 0);
+  gst_structure_get_int (structure, "channels", &new_chans);
+  this->is_int = (strcmp (gst_structure_get_name (structure),
+          "audio/x-raw-int") == 0);
 
   if (new_chans != this->channels) {
     need = new_chans - this->channels;
@@ -278,12 +267,12 @@ deinterleave_sink_link (GstPad *pad, const GstCaps *caps)
       for (p = g_list_last (this->srcpads); p;) {
         GstPad *peer, *pad = p->data;
         GList *old;
-			
+
         /* Check if they're connected */
         peer = GST_PAD_PEER (pad);
         if (peer)
           gst_pad_unlink (pad, peer);
-	
+
         gst_element_remove_pad (GST_ELEMENT (this), pad);
 
         old = p;
@@ -293,7 +282,7 @@ deinterleave_sink_link (GstPad *pad, const GstCaps *caps)
         if (p != NULL)
           p->next = NULL;
       }
-    } else {	
+    } else {
       /* Create that number of src pads */
       for (i = this->channels; i < new_chans; i++) {
         GstPad *pad;
@@ -301,7 +290,8 @@ deinterleave_sink_link (GstPad *pad, const GstCaps *caps)
 
         pad_name = g_strdup_printf ("src_%d", i);
         pad = gst_pad_new_from_template
-          (gst_static_pad_template_get (&deinterleave_src_template), pad_name);
+            (gst_static_pad_template_get (&deinterleave_src_template),
+            pad_name);
         g_free (pad_name);
 
         gst_pad_set_getcaps_function (pad, deinterleave_src_getcaps);
@@ -310,43 +300,43 @@ deinterleave_sink_link (GstPad *pad, const GstCaps *caps)
         this->srcpads = g_list_append (this->srcpads, pad);
       }
     }
-	
+
     this->channels = new_chans;
     deinterleave_free_channels_data (this);
     if (GST_STATE (this) == GST_STATE_PLAYING)
       deinterleave_alloc_channels_data (this);
     /* otherwise alloc in the state-change */
   }
-	
+
   srccaps = gst_caps_copy (caps);
   gst_caps_set_simple (srccaps, "channels", G_TYPE_INT, 1, NULL);
-  for (p=this->srcpads; p; p=p->next) {
+  for (p = this->srcpads; p; p = p->next) {
     srclink = gst_pad_try_set_caps (GST_PAD (p->data), srccaps);
     if (GST_PAD_LINK_FAILED (srclink)) {
       gst_caps_free (srccaps);
       return srclink;
     }
   }
-	
+
   gst_caps_free (srccaps);
 
   return GST_PAD_LINK_OK;
 }
 
 static GstElementStateReturn
-deinterleave_change_state (GstElement *element)
+deinterleave_change_state (GstElement * element)
 {
   Deinterleave *this = DEINTERLEAVE (element);
-	
+
   switch (GST_STATE_TRANSITION (element)) {
-  case GST_STATE_PAUSED_TO_PLAYING:
-    deinterleave_alloc_channels_data (this);
-    break;
-  case GST_STATE_READY_TO_NULL:
-    deinterleave_free_channels_data (this);
-    break;
-  default:
-    break;
+    case GST_STATE_PAUSED_TO_PLAYING:
+      deinterleave_alloc_channels_data (this);
+      break;
+    case GST_STATE_READY_TO_NULL:
+      deinterleave_free_channels_data (this);
+      break;
+    default:
+      break;
   }
 
   if (parent_class->change_state)
@@ -355,8 +345,7 @@ deinterleave_change_state (GstElement *element)
 }
 
 static void
-deinterleave_chain (GstPad *pad,
-                    GstData *_data)
+deinterleave_chain (GstPad * pad, GstData * _data)
 {
   GstBuffer *buf = GST_BUFFER (_data);
   Deinterleave *this;
@@ -365,7 +354,7 @@ deinterleave_chain (GstPad *pad,
   GstBuffer **out_bufs;
   GList *p;
   int i;
-	
+
   DEBUG;
 
   this = DEINTERLEAVE (gst_pad_get_parent (pad));
@@ -380,34 +369,35 @@ deinterleave_chain (GstPad *pad,
 
   if (this->channels == 0) {
     GST_ELEMENT_ERROR (this, CORE, NEGOTIATION, (NULL),
-                       ("format wasn't negotiated before chain function"));
+        ("format wasn't negotiated before chain function"));
     return;
   } else if (this->channels == 1) {
     gst_pad_push (GST_PAD (this->srcpads->data), GST_DATA (buf));
     return;
   }
-	
-  in_data = (gpointer)GST_BUFFER_DATA (buf);
+
+  in_data = (gpointer) GST_BUFFER_DATA (buf);
 
   /* Create our buffers */
   for (i = 0; i < this->channels; i++) {
-    out_bufs[i] = gst_buffer_new_and_alloc (GST_BUFFER_SIZE (buf) / this->channels);
+    out_bufs[i] =
+        gst_buffer_new_and_alloc (GST_BUFFER_SIZE (buf) / this->channels);
     gst_buffer_stamp (out_bufs[i], buf);
-    out_data[i] = (gpointer)GST_BUFFER_DATA (out_bufs[i]);
+    out_data[i] = (gpointer) GST_BUFFER_DATA (out_bufs[i]);
   }
 
   if (this->is_int) {
     do_int_deinterleave
-      ((gint16*)in_data,
-       this->channels,
-       (gint16**)out_data,
-       GST_BUFFER_SIZE (buf) / this->channels / sizeof(gint16));
+        ((gint16 *) in_data,
+        this->channels,
+        (gint16 **) out_data,
+        GST_BUFFER_SIZE (buf) / this->channels / sizeof (gint16));
   } else {
     do_float_deinterleave
-      ((gfloat*)in_data,
-       this->channels,
-       (gfloat**)out_data,
-       GST_BUFFER_SIZE (buf) / this->channels / sizeof(gfloat));
+        ((gfloat *) in_data,
+        this->channels,
+        (gfloat **) out_data,
+        GST_BUFFER_SIZE (buf) / this->channels / sizeof (gfloat));
   }
 
   gst_buffer_unref (buf);
@@ -417,23 +407,23 @@ deinterleave_chain (GstPad *pad,
 }
 
 static void inline
-do_int_deinterleave (gint16 *in_data, int channels,
-                     gint16 **out_data, guint numframes)
+do_int_deinterleave (gint16 * in_data, int channels,
+    gint16 ** out_data, guint numframes)
 {
   guint i, k;
 
   for (i = 0; i < numframes; i++)
     for (k = 0; k < channels; k++)
-      out_data[k][i] = in_data[channels*i + k];
+      out_data[k][i] = in_data[channels * i + k];
 }
 
 static void inline
-do_float_deinterleave (gfloat *in_data, int channels,
-                       gfloat **out_data, guint numframes)
+do_float_deinterleave (gfloat * in_data, int channels,
+    gfloat ** out_data, guint numframes)
 {
   guint i, k;
 
   for (i = 0; i < numframes; i++)
     for (k = 0; k < channels; k++)
-      out_data[k][i] = in_data[channels*i + k];
+      out_data[k][i] = in_data[channels * i + k];
 }
