@@ -25,6 +25,7 @@
 #include "config.h"
 #endif
 #include <gst/gst.h>
+#include <gst/audio/audio.h>
 #include "gstlevel.h"
 #include "math.h"
 
@@ -38,56 +39,30 @@ static GstElementDetails level_details = {
 
 /* pad templates */
 
-GST_PAD_TEMPLATE_FACTORY (sink_template_factory,
-  "level_sink",
-  GST_PAD_SINK,
-  GST_PAD_ALWAYS,
-  GST_CAPS_NEW (
-    "level_sink",
-    "audio/x-raw-int",
-      "signed", GST_PROPS_BOOLEAN (TRUE),
-      "width", GST_PROPS_LIST (
-                 GST_PROPS_INT (8),
-                 GST_PROPS_INT (16)
-               ),
-      "depth", GST_PROPS_LIST (
-                 GST_PROPS_INT (8),
-                 GST_PROPS_INT (16)
-               ),
-      "rate", GST_PROPS_INT_RANGE (1, G_MAXINT),
-      "channels", GST_PROPS_INT_RANGE (1, 2)
-  )
-)
+static GstStaticPadTemplate sink_template_factory =
+GST_STATIC_PAD_TEMPLATE ("level_sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS (GST_AUDIO_INT_PAD_TEMPLATE_CAPS)
+    );
 
-GST_PAD_TEMPLATE_FACTORY (src_template_factory,
-  "level_src",
-  GST_PAD_SRC,
-  GST_PAD_ALWAYS,
-  GST_CAPS_NEW (
-    "level_src",
-    "audio/x-raw-int",
-    "signed", GST_PROPS_BOOLEAN (TRUE),
-    "width", GST_PROPS_LIST (
-               GST_PROPS_INT (8),
-               GST_PROPS_INT (16)
-             ),
-    "depth", GST_PROPS_LIST (
-               GST_PROPS_INT (8),
-               GST_PROPS_INT (16)
-             ),
-    "rate", GST_PROPS_INT_RANGE (1, G_MAXINT),
-    "channels", GST_PROPS_INT_RANGE (1, 2)
-  )
-)
+static GstStaticPadTemplate src_template_factory =
+GST_STATIC_PAD_TEMPLATE ("level_src",
+    GST_PAD_SRC,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS (GST_AUDIO_INT_PAD_TEMPLATE_CAPS)
+    );
 
 /* Filter signals and args */
-enum {
+enum
+{
   /* FILL ME */
   SIGNAL_LEVEL,
   LAST_SIGNAL
 };
 
-enum {
+enum
+{
   ARG_0,
   ARG_SIGNAL_LEVEL,
   ARG_SIGNAL_INTERVAL,
@@ -95,56 +70,55 @@ enum {
   ARG_PEAK_FALLOFF
 };
 
-static void		gst_level_class_init		(GstLevelClass *klass);
-static void		gst_level_base_init		(GstLevelClass *klass);
-static void		gst_level_init			(GstLevel *filter);
+static void gst_level_class_init (GstLevelClass * klass);
+static void gst_level_base_init (GstLevelClass * klass);
+static void gst_level_init (GstLevel * filter);
 
-static GstElementStateReturn gst_level_change_state     (GstElement *element);
-static void		gst_level_set_property			(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
-static void		gst_level_get_property			(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
+static GstElementStateReturn gst_level_change_state (GstElement * element);
+static void gst_level_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
+static void gst_level_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
 
-static void		gst_level_chain			(GstPad *pad, GstData *_data);
+static void gst_level_chain (GstPad * pad, GstData * _data);
 
 static GstElementClass *parent_class = NULL;
 static guint gst_filter_signals[LAST_SIGNAL] = { 0 };
 
 GType
-gst_level_get_type (void) 
+gst_level_get_type (void)
 {
   static GType level_type = 0;
 
-  if (!level_type) 
-  {
-    static const GTypeInfo level_info = 
-    {
+  if (!level_type) {
+    static const GTypeInfo level_info = {
       sizeof (GstLevelClass),
       (GBaseInitFunc) gst_level_base_init, NULL,
       (GClassInitFunc) gst_level_class_init, NULL, NULL,
       sizeof (GstLevel), 0,
       (GInstanceInitFunc) gst_level_init
     };
-    level_type = g_type_register_static (GST_TYPE_ELEMENT, "GstLevel", 
-	                                 &level_info, 0);
+
+    level_type = g_type_register_static (GST_TYPE_ELEMENT, "GstLevel",
+        &level_info, 0);
   }
   return level_type;
 }
 
 static GstPadLinkReturn
-gst_level_link (GstPad *pad, GstCaps *caps)
+gst_level_link (GstPad * pad, const GstCaps * caps)
 {
   GstLevel *filter;
   GstPad *otherpad;
   GstPadLinkReturn res;
+  GstStructure *structure;
   int i;
+  gboolean ret;
 
   filter = GST_LEVEL (gst_pad_get_parent (pad));
   g_return_val_if_fail (filter != NULL, GST_PAD_LINK_REFUSED);
   g_return_val_if_fail (GST_IS_LEVEL (filter), GST_PAD_LINK_REFUSED);
   otherpad = (pad == filter->srcpad ? filter->sinkpad : filter->srcpad);
-	  
-  if (!GST_CAPS_IS_FIXED (caps)) {
-    return GST_PAD_LINK_DELAYED;
-  }
 
   res = gst_pad_try_set_caps (otherpad, caps);
   /* if ok, set filter */
@@ -153,22 +127,30 @@ gst_level_link (GstPad *pad, GstCaps *caps)
   }
 
   filter->num_samples = 0;
-  
-  if (!gst_caps_get_int (caps, "rate", &(filter->rate)))
-    return GST_PAD_LINK_REFUSED;
-  if (!gst_caps_get_int (caps, "width", &(filter->width)))
-    return GST_PAD_LINK_REFUSED;
-  if (!gst_caps_get_int (caps, "channels", &(filter->channels)))
+
+  structure = gst_caps_get_structure (caps, 0);
+  ret = gst_structure_get_int (structure, "rate", &filter->rate);
+  ret &= gst_structure_get_int (structure, "width", &filter->width);
+  ret &= gst_structure_get_int (structure, "channels", &filter->channels);
+
+  if (!ret)
     return GST_PAD_LINK_REFUSED;
 
   /* allocate channel variable arrays */
-  if (filter->CS) g_free (filter->CS);
-  if (filter->peak) g_free (filter->peak);
-  if (filter->last_peak) g_free (filter->last_peak);
-  if (filter->decay_peak) g_free (filter->decay_peak);
-  if (filter->decay_peak_age) g_free (filter->decay_peak_age);
-  if (filter->MS) g_free (filter->MS);
-  if (filter->RMS_dB) g_free (filter->RMS_dB);
+  if (filter->CS)
+    g_free (filter->CS);
+  if (filter->peak)
+    g_free (filter->peak);
+  if (filter->last_peak)
+    g_free (filter->last_peak);
+  if (filter->decay_peak)
+    g_free (filter->decay_peak);
+  if (filter->decay_peak_age)
+    g_free (filter->decay_peak_age);
+  if (filter->MS)
+    g_free (filter->MS);
+  if (filter->RMS_dB)
+    g_free (filter->RMS_dB);
   filter->CS = g_new (double, filter->channels);
   filter->peak = g_new (double, filter->channels);
   filter->last_peak = g_new (double, filter->channels);
@@ -176,10 +158,11 @@ gst_level_link (GstPad *pad, GstCaps *caps)
   filter->decay_peak_age = g_new (double, filter->channels);
   filter->MS = g_new (double, filter->channels);
   filter->RMS_dB = g_new (double, filter->channels);
+
   for (i = 0; i < filter->channels; ++i) {
     filter->CS[i] = filter->peak[i] = filter->last_peak[i] =
-                    filter->decay_peak[i] = filter->decay_peak_age[i] = 
-                    filter->MS[i] = filter->RMS_dB[i] = 0.0;
+        filter->decay_peak[i] = filter->decay_peak_age[i] =
+        filter->MS[i] = filter->RMS_dB[i] = 0.0;
   }
 
   filter->inited = TRUE;
@@ -188,17 +171,14 @@ gst_level_link (GstPad *pad, GstCaps *caps)
 }
 
 static void inline
-gst_level_fast_16bit_chain (gint16* in, guint num, gint channels, 
-                            gint resolution, double *CS, double *peak)
+gst_level_fast_16bit_chain (gint16 * in, guint num, gint channels,
+    gint resolution, double *CS, double *peak)
 #include "filter.func"
-
-static void inline
-gst_level_fast_8bit_chain (gint8* in, guint num, gint channels, 
-                           gint resolution, double *CS, double *peak)
+     static void inline
+         gst_level_fast_8bit_chain (gint8 * in, guint num, gint channels,
+    gint resolution, double *CS, double *peak)
 #include "filter.func"
-
-static void
-gst_level_chain (GstPad *pad, GstData *_data)
+     static void gst_level_chain (GstPad * pad, GstData * _data)
 {
   GstBuffer *buf = GST_BUFFER (_data);
   GstLevel *filter;
@@ -218,27 +198,24 @@ gst_level_chain (GstPad *pad, GstData *_data)
 
   for (i = 0; i < filter->channels; ++i)
     filter->CS[i] = filter->peak[i] = filter->MS[i] = filter->RMS_dB[i] = 0.0;
-  
+
   in_data = (gint16 *) GST_BUFFER_DATA (buf);
-  
+
   num_samples = GST_BUFFER_SIZE (buf) / (filter->width / 8);
   if (num_samples % filter->channels != 0)
-    g_warning ("WARNING: level: programming error, data not properly interleaved");
+    g_warning
+        ("WARNING: level: programming error, data not properly interleaved");
 
-  for (i = 0; i < filter->channels; ++i)
-  {
-    switch (filter->width)
-    {
+  for (i = 0; i < filter->channels; ++i) {
+    switch (filter->width) {
       case 16:
-	  gst_level_fast_16bit_chain (in_data + i, num_samples,
-                                      filter->channels, filter->width - 1,
-                                      &CS, &filter->peak[i]);
-	  break;
+        gst_level_fast_16bit_chain (in_data + i, num_samples,
+            filter->channels, filter->width - 1, &CS, &filter->peak[i]);
+        break;
       case 8:
-	  gst_level_fast_8bit_chain (((gint8 *) in_data) + i, num_samples,
-                                     filter->channels, filter->width - 1,
-                                     &CS, &filter->peak[i]);
-	  break;
+        gst_level_fast_8bit_chain (((gint8 *) in_data) + i, num_samples,
+            filter->channels, filter->width - 1, &CS, &filter->peak[i]);
+        break;
     }
     /* g_print ("DEBUG: CS %f, peak %f\n", CS, filter->peak[i]); */
     filter->CS[i] += CS;
@@ -248,64 +225,57 @@ gst_level_chain (GstPad *pad, GstData *_data)
 
   filter->num_samples += num_samples;
 
-  for (i = 0; i < filter->channels; ++i)
-  {
+  for (i = 0; i < filter->channels; ++i) {
     filter->decay_peak_age[i] += num_samples;
     /* g_print ("filter peak info [%d]: peak %f, age %f\n", i, 
-             filter->last_peak[i], filter->decay_peak_age[i]); */
+       filter->last_peak[i], filter->decay_peak_age[i]); */
     /* update running peak */
     if (filter->peak[i] > filter->last_peak[i])
-        filter->last_peak[i] = filter->peak[i];
+      filter->last_peak[i] = filter->peak[i];
 
     /* update decay peak */
-    if (filter->peak[i] >= filter->decay_peak[i])
-    {
-       /* g_print ("new peak, %f\n", filter->peak[i]); */
-       filter->decay_peak[i] = filter->peak[i];
-       filter->decay_peak_age[i] = 0;
-    }
-    else
-    {
+    if (filter->peak[i] >= filter->decay_peak[i]) {
+      /* g_print ("new peak, %f\n", filter->peak[i]); */
+      filter->decay_peak[i] = filter->peak[i];
+      filter->decay_peak_age[i] = 0;
+    } else {
       /* make decay peak fall off if too old */
-      if (filter->decay_peak_age[i] > filter->rate * filter->decay_peak_ttl)
-      {
+      if (filter->decay_peak_age[i] > filter->rate * filter->decay_peak_ttl) {
         double falloff_dB;
         double falloff;
-        double length;		/* length of buffer in seconds */
+        double length;          /* length of buffer in seconds */
+
 
- 
         length = (double) num_samples / (filter->channels * filter->rate);
         falloff_dB = filter->decay_peak_falloff * length;
         falloff = pow (10, falloff_dB / -20.0);
 
         /* g_print ("falloff: length %f, dB falloff %f, falloff factor %e\n",
-                 length, falloff_dB, falloff); */
+           length, falloff_dB, falloff); */
         filter->decay_peak[i] *= falloff;
         /* g_print ("peak is %f samples old, decayed with factor %e to %f\n",
-                 filter->decay_peak_age[i], falloff, filter->decay_peak[i]); */
+           filter->decay_peak_age[i], falloff, filter->decay_peak[i]); */
       }
     }
   }
 
   /* do we need to emit ? */
-  
-  if (filter->num_samples >= filter->interval * (gdouble) filter->rate)
-  {
-    if (filter->signal)
-    {
+
+  if (filter->num_samples >= filter->interval * (gdouble) filter->rate) {
+    if (filter->signal) {
       gdouble RMS, peak, endtime;
-      for (i = 0; i < filter->channels; ++i)
-      {
+
+      for (i = 0; i < filter->channels; ++i) {
         RMS = sqrt (filter->CS[i] / (filter->num_samples / filter->channels));
         peak = filter->last_peak[i];
         num_samples = GST_BUFFER_SIZE (buf) / (filter->width / 8);
         endtime = (double) GST_BUFFER_TIMESTAMP (buf) / GST_SECOND
-                + (double) num_samples / (double) filter->rate;
+            + (double) num_samples / (double) filter->rate;
 
         g_signal_emit (G_OBJECT (filter), gst_filter_signals[SIGNAL_LEVEL], 0,
-                       endtime, i,
-                       20 * log10 (RMS), 20 * log10 (filter->last_peak[i]),
-                       20 * log10 (filter->decay_peak[i]));
+            endtime, i,
+            20 * log10 (RMS), 20 * log10 (filter->last_peak[i]),
+            20 * log10 (filter->decay_peak[i]));
         /* we emitted, so reset cumulative and normal peak */
         filter->CS[i] = 0.0;
         filter->last_peak[i] = 0.0;
@@ -315,24 +285,26 @@ gst_level_chain (GstPad *pad, GstData *_data)
   }
 }
 
-static GstElementStateReturn gst_level_change_state (GstElement *element)
+static GstElementStateReturn
+gst_level_change_state (GstElement * element)
 {
   GstLevel *filter = GST_LEVEL (element);
 
-  switch(GST_STATE_TRANSITION(element)){
+  switch (GST_STATE_TRANSITION (element)) {
     case GST_STATE_PAUSED_TO_PLAYING:
-      if (!filter->inited) return GST_STATE_FAILURE;
+      if (!filter->inited)
+        return GST_STATE_FAILURE;
       break;
     default:
       break;
   }
 
-  return GST_ELEMENT_CLASS(parent_class)->change_state(element);
+  return GST_ELEMENT_CLASS (parent_class)->change_state (element);
 }
 
 static void
-gst_level_set_property (GObject *object, guint prop_id, 
-                        const GValue *value, GParamSpec *pspec)
+gst_level_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   GstLevel *filter;
 
@@ -359,8 +331,8 @@ gst_level_set_property (GObject *object, guint prop_id,
 }
 
 static void
-gst_level_get_property (GObject *object, guint prop_id, 
-                        GValue *value, GParamSpec *pspec)
+gst_level_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec)
 {
   GstLevel *filter;
 
@@ -372,7 +344,7 @@ gst_level_get_property (GObject *object, guint prop_id,
     case ARG_SIGNAL_LEVEL:
       g_value_set_boolean (value, filter->signal);
       break;
-      case ARG_SIGNAL_INTERVAL:
+    case ARG_SIGNAL_INTERVAL:
       g_value_set_double (value, filter->interval);
       break;
     case ARG_PEAK_TTL:
@@ -381,72 +353,76 @@ gst_level_get_property (GObject *object, guint prop_id,
     case ARG_PEAK_FALLOFF:
       g_value_set_double (value, filter->decay_peak_falloff);
       break;
-   default:
+    default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
   }
 }
 
 static void
-gst_level_base_init (GstLevelClass *klass)
+gst_level_base_init (GstLevelClass * klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   gst_element_class_add_pad_template (element_class,
-	GST_PAD_TEMPLATE_GET (sink_template_factory));
+      gst_static_pad_template_get (&sink_template_factory));
   gst_element_class_add_pad_template (element_class,
-	GST_PAD_TEMPLATE_GET (src_template_factory));
+      gst_static_pad_template_get (&src_template_factory));
   gst_element_class_set_details (element_class, &level_details);
 
   element_class->change_state = gst_level_change_state;
 }
 
 static void
-gst_level_class_init (GstLevelClass *klass)
+gst_level_class_init (GstLevelClass * klass)
 {
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
 
-  gobject_class = (GObjectClass*) klass;
-  gstelement_class = (GstElementClass*) klass;
+  gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SIGNAL_LEVEL,
-    g_param_spec_boolean ("signal", "Signal",
-                          "Emit level signals for each interval",
-                          TRUE, G_PARAM_READWRITE));
+      g_param_spec_boolean ("signal", "Signal",
+          "Emit level signals for each interval", TRUE, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_SIGNAL_INTERVAL,
-    g_param_spec_double ("interval", "Interval",
-                         "Interval between emissions (in seconds)",
-                         0.01, 100.0, 0.1, G_PARAM_READWRITE));
+      g_param_spec_double ("interval", "Interval",
+          "Interval between emissions (in seconds)",
+          0.01, 100.0, 0.1, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_PEAK_TTL,
-    g_param_spec_double ("peak_ttl", "Peak TTL",
-                         "Time To Live of decay peak before it falls back",
-                         0, 100.0, 0.3, G_PARAM_READWRITE));
+      g_param_spec_double ("peak_ttl", "Peak TTL",
+          "Time To Live of decay peak before it falls back",
+          0, 100.0, 0.3, G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_PEAK_FALLOFF,
-    g_param_spec_double ("peak_falloff", "Peak Falloff",
-                         "Decay rate of decay peak after TTL (in dB/sec)",
-                         0.0, G_MAXDOUBLE, 10.0, G_PARAM_READWRITE));
+      g_param_spec_double ("peak_falloff", "Peak Falloff",
+          "Decay rate of decay peak after TTL (in dB/sec)",
+          0.0, G_MAXDOUBLE, 10.0, G_PARAM_READWRITE));
 
   gobject_class->set_property = gst_level_set_property;
   gobject_class->get_property = gst_level_get_property;
 
-  gst_filter_signals[SIGNAL_LEVEL] = 
-    g_signal_new ("level", G_TYPE_FROM_CLASS(klass), G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GstLevelClass, level), NULL, NULL,
-                  gstlevel_cclosure_marshal_VOID__DOUBLE_INT_DOUBLE_DOUBLE_DOUBLE,
-                  G_TYPE_NONE, 5,
-                  G_TYPE_DOUBLE, G_TYPE_INT,
-                  G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE);
+  gst_filter_signals[SIGNAL_LEVEL] =
+      g_signal_new ("level", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST,
+      G_STRUCT_OFFSET (GstLevelClass, level), NULL, NULL,
+      gstlevel_cclosure_marshal_VOID__DOUBLE_INT_DOUBLE_DOUBLE_DOUBLE,
+      G_TYPE_NONE, 5,
+      G_TYPE_DOUBLE, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE);
 }
 
 static void
-gst_level_init (GstLevel *filter)
+gst_level_init (GstLevel * filter)
 {
-  filter->sinkpad = gst_pad_new_from_template (GST_PAD_TEMPLATE_GET (sink_template_factory), "sink");
+  filter->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&sink_template_factory), "sink");
   gst_pad_set_link_function (filter->sinkpad, gst_level_link);
-  filter->srcpad = gst_pad_new_from_template (GST_PAD_TEMPLATE_GET (src_template_factory), "src");
+  gst_pad_set_getcaps_function (filter->sinkpad, gst_pad_proxy_getcaps);
+  filter->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&src_template_factory), "src");
   gst_pad_set_link_function (filter->srcpad, gst_level_link);
+  gst_pad_set_getcaps_function (filter->srcpad, gst_pad_proxy_getcaps);
 
   gst_element_add_pad (GST_ELEMENT (filter), filter->sinkpad);
   gst_pad_set_chain_function (filter->sinkpad, gst_level_chain);
@@ -464,24 +440,17 @@ gst_level_init (GstLevel *filter)
 
   filter->interval = 0.1;
   filter->decay_peak_ttl = 0.4;
-  filter->decay_peak_falloff = 10.0;	/* dB falloff (/sec) */
+  filter->decay_peak_falloff = 10.0;    /* dB falloff (/sec) */
 }
 
 static gboolean
-plugin_init (GstPlugin *plugin)
+plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "level",
-			       GST_RANK_NONE, GST_TYPE_LEVEL);
+  return gst_element_register (plugin, "level", GST_RANK_NONE, GST_TYPE_LEVEL);
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "level",
-  "Audio level plugin",
-  plugin_init,
-  VERSION,
-  GST_LICENSE,
-  GST_PACKAGE,
-  GST_ORIGIN
-)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "level",
+    "Audio level plugin",
+    plugin_init, VERSION, GST_LICENSE, GST_PACKAGE, GST_ORIGIN)
