@@ -1099,7 +1099,9 @@ gst_matroska_demux_handle_seek_event (GstMatroskaDemux * demux)
   if (!(event = gst_ebml_read_seek (ebml, entry->pos + demux->segment_start)))
     return FALSE;
   gst_event_unref (event);      /* byte - we want time */
-  event = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, entry->time);
+  event =
+      gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, entry->time,
+      GST_FORMAT_UNDEFINED);
 
   /* forward to all src pads */
   for (i = 0; i < demux->num_streams; i++) {
@@ -2551,7 +2553,8 @@ gst_matroska_demux_plugin_init (GstPlugin * plugin)
     /* TODO: Real/Quicktime */
     /* FILLME */
     NULL,
-  }, *audio_id[] = {
+  }, *audio_id[] =
+  {
     GST_MATROSKA_CODEC_ID_AUDIO_MPEG1_L1,
         GST_MATROSKA_CODEC_ID_AUDIO_MPEG1_L2,
         GST_MATROSKA_CODEC_ID_AUDIO_MPEG1_L3,
@@ -2564,9 +2567,11 @@ gst_matroska_demux_plugin_init (GstPlugin * plugin)
         GST_MATROSKA_CODEC_ID_AUDIO_MPEG2, GST_MATROSKA_CODEC_ID_AUDIO_MPEG4,
         /* TODO: AC3-9/10, Real, Musepack, Quicktime */
         /* FILLME */
-  NULL,}, *complex_id[] = {
+  NULL,}
+  , *complex_id[] = {
     /* FILLME */
-  NULL,}, *subtitle_id[] = {
+  NULL,}
+  , *subtitle_id[] = {
     /* FILLME */
   NULL,};
 
