@@ -28,18 +28,19 @@ static GstElementDetails gst_mpegaudio_details = {
   "mpegaudio mp3 encoder",
   "Codec/Encoder/Audio",
   "Uses modified mpegaudio code to encode to mp3 streams",
-  "Erik Walthinsen <omega@cse.ogi.edu>\n"
-  "Wim Taymans <wim.taymans@chello.be>"
+  "Erik Walthinsen <omega@cse.ogi.edu>\n" "Wim Taymans <wim.taymans@chello.be>"
 };
 
 
 /* MpegAudio signals and args */
-enum {
+enum
+{
   /* FILL ME */
   LAST_SIGNAL
 };
 
-enum {
+enum
+{
   ARG_0,
   ARG_MODE,
   ARG_LAYER,
@@ -50,32 +51,26 @@ enum {
 };
 
 static GstStaticPadTemplate mpegaudio_sink_templ =
-GST_STATIC_PAD_TEMPLATE (
-  "sink",
-  GST_PAD_SINK,
-  GST_PAD_ALWAYS,
-  GST_STATIC_CAPS ("audio/x-raw-int, "
-      "endianness = (int) BYTE_ORDER, "
-      "signed = (boolean) true, "
-      "width = (int) 16, "
-      "depth = (int) 16, "
-      "rate = (int) { 32000, 44100, 48000 }, "
-      "channels = (int) [ 1, 2 ]"
-  )
-);
+GST_STATIC_PAD_TEMPLATE ("sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("audio/x-raw-int, "
+        "endianness = (int) BYTE_ORDER, "
+        "signed = (boolean) true, "
+        "width = (int) 16, "
+        "depth = (int) 16, "
+        "rate = (int) { 32000, 44100, 48000 }, " "channels = (int) [ 1, 2 ]")
+    );
 
 static GstStaticPadTemplate mpegaudio_src_templ =
-GST_STATIC_PAD_TEMPLATE (
-  "src",
-  GST_PAD_SRC,
-  GST_PAD_ALWAYS,
-  GST_STATIC_CAPS ("audio/mpeg, "
-      "mpegversion = (int) 1, "
-      "layer = (int) [ 1, 2 ], "
-      "channels = (int) [ 1, 2 ], "
-      "rate = [ 8000, 96000 ]"
-  )
-);
+GST_STATIC_PAD_TEMPLATE ("src",
+    GST_PAD_SRC,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS ("audio/mpeg, "
+        "mpegversion = (int) 1, "
+        "layer = (int) [ 1, 2 ], "
+        "channels = (int) [ 1, 2 ], " "rate = [ 8000, 96000 ]")
+    );
 
 /********** Define useful types for non-programmatic interfaces **********/
 #define GST_TYPE_MPEGAUDIO_MODE (gst_mpegaudio_mode_get_type())
@@ -84,28 +79,32 @@ gst_mpegaudio_mode_get_type (void)
 {
   static GType mpegaudio_mode_type = 0;
   static GEnumValue mpegaudio_modes[] = {
-    { MPG_MD_STEREO, 		"0", "Stereo" },
-    { MPG_MD_JOINT_STEREO, 	"1", "Joint-Stereo" },
-    { MPG_MD_DUAL_CHANNEL, 	"2", "Dual channel" },
-    { MPG_MD_MONO, 		"3", "Mono" },
-    { 0, NULL, NULL },
+    {MPG_MD_STEREO, "0", "Stereo"},
+    {MPG_MD_JOINT_STEREO, "1", "Joint-Stereo"},
+    {MPG_MD_DUAL_CHANNEL, "2", "Dual channel"},
+    {MPG_MD_MONO, "3", "Mono"},
+    {0, NULL, NULL},
   };
   if (!mpegaudio_mode_type) {
-    mpegaudio_mode_type = g_enum_register_static ("GstMpegAudioMode", mpegaudio_modes);
+    mpegaudio_mode_type =
+        g_enum_register_static ("GstMpegAudioMode", mpegaudio_modes);
   }
   return mpegaudio_mode_type;
 }
 
-static void	gst_mpegaudio_class_init	(GstMpegAudioClass *klass);
-static void	gst_mpegaudio_base_init		(GstMpegAudioClass *klass);
-static void	gst_mpegaudio_init		(GstMpegAudio *mpegaudio);
+static void gst_mpegaudio_class_init (GstMpegAudioClass * klass);
+static void gst_mpegaudio_base_init (GstMpegAudioClass * klass);
+static void gst_mpegaudio_init (GstMpegAudio * mpegaudio);
 
-static void	gst_mpegaudio_chain		(GstPad *pad, GstData *_data);
+static void gst_mpegaudio_chain (GstPad * pad, GstData * _data);
 
-static void 	gst_mpegaudio_get_property 		(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
-static void 	gst_mpegaudio_set_property 		(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
+static void gst_mpegaudio_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec);
+static void gst_mpegaudio_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec);
 
 static GstElementClass *parent_class = NULL;
+
 /*static guint gst_mpegaudio_signals[LAST_SIGNAL] = { 0 }; */
 
 GType
@@ -115,59 +114,52 @@ gst_mpegaudio_get_type (void)
 
   if (!mpegaudio_type) {
     static const GTypeInfo mpegaudio_info = {
-      sizeof(GstMpegAudioClass),
-      (GBaseInitFunc)gst_mpegaudio_base_init,
+      sizeof (GstMpegAudioClass),
+      (GBaseInitFunc) gst_mpegaudio_base_init,
       NULL,
-      (GClassInitFunc)gst_mpegaudio_class_init,
+      (GClassInitFunc) gst_mpegaudio_class_init,
       NULL,
       NULL,
-      sizeof(GstMpegAudio),
+      sizeof (GstMpegAudio),
       0,
-      (GInstanceInitFunc)gst_mpegaudio_init,
+      (GInstanceInitFunc) gst_mpegaudio_init,
     };
-    mpegaudio_type = g_type_register_static(GST_TYPE_ELEMENT, "GstMpegAudio", &mpegaudio_info, 0);
+    mpegaudio_type =
+        g_type_register_static (GST_TYPE_ELEMENT, "GstMpegAudio",
+        &mpegaudio_info, 0);
   }
   return mpegaudio_type;
 }
 
 static void
-gst_mpegaudio_base_init (GstMpegAudioClass *klass)
+gst_mpegaudio_base_init (GstMpegAudioClass * klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   gst_element_class_add_pad_template (element_class,
-		gst_static_pad_template_get (&mpegaudio_sink_templ));
+      gst_static_pad_template_get (&mpegaudio_sink_templ));
   gst_element_class_add_pad_template (element_class,
-		gst_static_pad_template_get (&mpegaudio_src_templ));
+      gst_static_pad_template_get (&mpegaudio_src_templ));
   gst_element_class_set_details (element_class, &gst_mpegaudio_details);
 }
 
 static void
-gst_mpegaudio_class_init (GstMpegAudioClass *klass)
+gst_mpegaudio_class_init (GstMpegAudioClass * klass)
 {
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
 
-  gobject_class = (GObjectClass*)klass;
-  gstelement_class = (GstElementClass*)klass;
+  gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
 
-  g_object_class_install_property(G_OBJECT_CLASS(klass), ARG_MODE,
-    g_param_spec_enum("mode","mode","mode",
-                      GST_TYPE_MPEGAUDIO_MODE,0,G_PARAM_READWRITE)); /* CHECKME! */
-  g_object_class_install_property(G_OBJECT_CLASS(klass), ARG_LAYER,
-    g_param_spec_int("layer","layer","layer",
-                     1, 3, 1, G_PARAM_READWRITE));
-  g_object_class_install_property(G_OBJECT_CLASS(klass), ARG_MODEL,
-    g_param_spec_int("model","model","model",
-                     G_MININT,G_MAXINT,0,G_PARAM_READWRITE)); /* CHECKME */
-  g_object_class_install_property(G_OBJECT_CLASS(klass), ARG_BITRATE,
-    g_param_spec_int("bitrate","bitrate","bitrate",
-                     G_MININT,G_MAXINT,0,G_PARAM_READWRITE)); /* CHECKME */
-  g_object_class_install_property(G_OBJECT_CLASS(klass), ARG_EMPHASIS,
-    g_param_spec_int("emphasis","emphasis","emphasis",
-                     G_MININT,G_MAXINT,0,G_PARAM_READWRITE)); /* CHECKME */
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MODE, g_param_spec_enum ("mode", "mode", "mode", GST_TYPE_MPEGAUDIO_MODE, 0, G_PARAM_READWRITE));        /* CHECKME! */
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LAYER,
+      g_param_spec_int ("layer", "layer", "layer", 1, 3, 1, G_PARAM_READWRITE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MODEL, g_param_spec_int ("model", "model", "model", G_MININT, G_MAXINT, 0, G_PARAM_READWRITE));  /* CHECKME */
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_BITRATE, g_param_spec_int ("bitrate", "bitrate", "bitrate", G_MININT, G_MAXINT, 0, G_PARAM_READWRITE));  /* CHECKME */
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_EMPHASIS, g_param_spec_int ("emphasis", "emphasis", "emphasis", G_MININT, G_MAXINT, 0, G_PARAM_READWRITE));      /* CHECKME */
 
-  parent_class = g_type_class_ref(GST_TYPE_ELEMENT);
+  parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   gobject_class->set_property = gst_mpegaudio_set_property;
   gobject_class->get_property = gst_mpegaudio_get_property;
@@ -175,7 +167,7 @@ gst_mpegaudio_class_init (GstMpegAudioClass *klass)
 }
 
 static GstPadLinkReturn
-gst_mpegaudio_sinkconnect (GstPad *pad, const GstCaps *caps)
+gst_mpegaudio_sinkconnect (GstPad * pad, const GstCaps * caps)
 {
   GstMpegAudio *mpegaudio;
   gint frequency, channels;
@@ -185,8 +177,8 @@ gst_mpegaudio_sinkconnect (GstPad *pad, const GstCaps *caps)
 
   structure = gst_caps_get_structure (caps, 0);
 
-  gst_structure_get_int  (structure, "rate", &frequency);
-  gst_structure_get_int  (structure, "channels", &channels);
+  gst_structure_get_int (structure, "rate", &frequency);
+  gst_structure_get_int (structure, "channels", &channels);
   mpegaudio->encoder->frequency = frequency;
 
   if (channels == 1)
@@ -197,34 +189,35 @@ gst_mpegaudio_sinkconnect (GstPad *pad, const GstCaps *caps)
   caps = gst_caps_new_simple ("audio/mpeg",
       "mpegversion", G_TYPE_INT, 1,
       "layer", G_TYPE_INT, mpegaudio->encoder->info.lay,
-      "channels", G_TYPE_INT, channels,
-      "rate",  G_TYPE_INT, frequency, NULL);
+      "channels", G_TYPE_INT, channels, "rate", G_TYPE_INT, frequency, NULL);
 
   return gst_pad_try_set_caps (mpegaudio->srcpad, caps);
 }
 
 static void
-gst_mpegaudio_init (GstMpegAudio *mpegaudio)
+gst_mpegaudio_init (GstMpegAudio * mpegaudio)
 {
   /* create the sink and src pads */
-  mpegaudio->sinkpad = gst_pad_new_from_template (
-		  gst_static_pad_template_get (&mpegaudio_sink_templ), "sink");
+  mpegaudio->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&mpegaudio_sink_templ), "sink");
   gst_element_add_pad (GST_ELEMENT (mpegaudio), mpegaudio->sinkpad);
   gst_pad_set_chain_function (mpegaudio->sinkpad, gst_mpegaudio_chain);
   gst_pad_set_link_function (mpegaudio->sinkpad, gst_mpegaudio_sinkconnect);
 
-  mpegaudio->srcpad = gst_pad_new_from_template (
-		  gst_static_pad_template_get (&mpegaudio_src_templ), "src");
+  mpegaudio->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&mpegaudio_src_templ), "src");
   gst_element_add_pad (GST_ELEMENT (mpegaudio), mpegaudio->srcpad);
 
   /* initialize the mpegaudio encoder state */
-  mpegaudio->encoder = mpegaudio_init_encoder();
+  mpegaudio->encoder = mpegaudio_init_encoder ();
   mpegaudio->partialbuf = NULL;
   mpegaudio->partialsize = 0;
 }
 
 static void
-gst_mpegaudio_chain (GstPad *pad, GstData *_data)
+gst_mpegaudio_chain (GstPad * pad, GstData * _data)
 {
   GstBuffer *buf = GST_BUFFER (_data);
   GstMpegAudio *mpegaudio;
@@ -233,41 +226,43 @@ gst_mpegaudio_chain (GstPad *pad, GstData *_data)
   GstBuffer *outbuf;
   guint handled, tohandle;
 
-  g_return_if_fail(pad != NULL);
-  g_return_if_fail(GST_IS_PAD(pad));
-  g_return_if_fail(buf != NULL);
+  g_return_if_fail (pad != NULL);
+  g_return_if_fail (GST_IS_PAD (pad));
+  g_return_if_fail (buf != NULL);
 /*  g_return_if_fail(GST_IS_BUFFER(buf)); */
 
   mpegaudio = GST_MPEGAUDIO (gst_pad_get_parent (pad));
 
-  data = (guchar *)GST_BUFFER_DATA(buf);
-  size = GST_BUFFER_SIZE(buf);
+  data = (guchar *) GST_BUFFER_DATA (buf);
+  size = GST_BUFFER_SIZE (buf);
 
-  GST_DEBUG ("gst_mpegaudio_chain: got buffer of %ld bytes in '%s'",size,
-          GST_OBJECT_NAME (mpegaudio));
+  GST_DEBUG ("gst_mpegaudio_chain: got buffer of %ld bytes in '%s'", size,
+      GST_OBJECT_NAME (mpegaudio));
 
   handled = 0;
-  tohandle = mpegaudio_get_number_of_input_bytes(mpegaudio->encoder);
+  tohandle = mpegaudio_get_number_of_input_bytes (mpegaudio->encoder);
 
   if (mpegaudio->partialbuf) {
-     mpegaudio->partialbuf = g_realloc(mpegaudio->partialbuf, mpegaudio->partialsize+size);
-     memcpy(mpegaudio->partialbuf+mpegaudio->partialsize, data,size);
+    mpegaudio->partialbuf =
+        g_realloc (mpegaudio->partialbuf, mpegaudio->partialsize + size);
+    memcpy (mpegaudio->partialbuf + mpegaudio->partialsize, data, size);
 
-     data = mpegaudio->partialbuf;
-     size += mpegaudio->partialsize;
+    data = mpegaudio->partialbuf;
+    size += mpegaudio->partialsize;
   }
 
   GST_DEBUG ("need to handle %d bytes", tohandle);
-  while (handled+tohandle < size) {
+  while (handled + tohandle < size) {
 
-    outbuf = gst_buffer_new();
-    GST_BUFFER_DATA(outbuf) = g_malloc(tohandle);
+    outbuf = gst_buffer_new ();
+    GST_BUFFER_DATA (outbuf) = g_malloc (tohandle);
 
     GST_DEBUG ("about to encode a frame");
-    mpegaudio_encode_frame(mpegaudio->encoder,data, GST_BUFFER_DATA(outbuf), (gulong *)&GST_BUFFER_SIZE(outbuf));
+    mpegaudio_encode_frame (mpegaudio->encoder, data, GST_BUFFER_DATA (outbuf),
+        (gulong *) & GST_BUFFER_SIZE (outbuf));
 
-    GST_DEBUG ("mpegaudio: pushing %d bytes", GST_BUFFER_SIZE(outbuf));
-    gst_pad_push(mpegaudio->srcpad,GST_DATA (outbuf));
+    GST_DEBUG ("mpegaudio: pushing %d bytes", GST_BUFFER_SIZE (outbuf));
+    gst_pad_push (mpegaudio->srcpad, GST_DATA (outbuf));
     GST_DEBUG ("mpegaudio: pushed buffer");
 
     data += tohandle;
@@ -278,23 +273,23 @@ gst_mpegaudio_chain (GstPad *pad, GstData *_data)
     GST_DEBUG ("mpegaudio: leftover buffer %ld bytes", size - handled);
 
     if (!mpegaudio->partialbuf) {
-      mpegaudio->partialbuf = g_malloc(size-handled);
+      mpegaudio->partialbuf = g_malloc (size - handled);
     }
-    memcpy(mpegaudio->partialbuf, data, size-handled);
-    mpegaudio->partialsize = size-handled;
-  }
-  else {
+    memcpy (mpegaudio->partialbuf, data, size - handled);
+    mpegaudio->partialsize = size - handled;
+  } else {
     if (mpegaudio->partialbuf) {
-      g_free(mpegaudio->partialbuf);
+      g_free (mpegaudio->partialbuf);
       mpegaudio->partialbuf = NULL;
     }
   }
 
-  gst_buffer_unref(buf);
+  gst_buffer_unref (buf);
 }
 
 static void
-gst_mpegaudio_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+gst_mpegaudio_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstMpegAudio *mpegaudio;
 
@@ -325,7 +320,8 @@ gst_mpegaudio_get_property (GObject *object, guint prop_id, GValue *value, GPara
 }
 
 static void
-gst_mpegaudio_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+gst_mpegaudio_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   GstMpegAudio *mpegaudio;
 
@@ -356,20 +352,14 @@ gst_mpegaudio_set_property (GObject *object, guint prop_id, const GValue *value,
 }
 
 static gboolean
-plugin_init (GstPlugin *plugin)
+plugin_init (GstPlugin * plugin)
 {
   return gst_element_register (plugin, "mpegaudio",
-			       GST_RANK_NONE, GST_TYPE_MPEGAUDIO);
+      GST_RANK_NONE, GST_TYPE_MPEGAUDIO);
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "mpegaudio",
-  "MPEG-1 layer 1/2 audio encoder",
-  plugin_init,
-  VERSION,
-  "LGPL",
-  GST_PACKAGE,
-  GST_ORIGIN
-)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "mpegaudio",
+    "MPEG-1 layer 1/2 audio encoder",
+    plugin_init, VERSION, "LGPL", GST_PACKAGE, GST_ORIGIN)
