@@ -22,7 +22,8 @@
 #define __GST_QTDEMUX_H__
 
 #include <gst/gst.h>
-#include <gst/gstbytestream.h>
+#include <gst/bytestream/bytestream.h>
+#include <gst/getbits/getbits.h>
 
 #ifdef __cplusplus
 extern "C" {
