@@ -135,6 +135,7 @@ gst_video_crop_get_type (void)
       0,
       (GInstanceInitFunc) gst_video_crop_init,
     };
+
     video_crop_type =
         g_type_register_static (GST_TYPE_ELEMENT, "GstVideoCrop",
         &video_crop_info, 0);
@@ -419,7 +420,7 @@ gst_video_crop_change_state (GstElement * element)
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "videocrop", GST_RANK_PRIMARY,
+  return gst_element_register (plugin, "videocrop", GST_RANK_NONE,
       GST_TYPE_VIDEO_CROP);
 }
 
