@@ -38,10 +38,9 @@
 #include <sys/types.h>
 #define _LINUX_TIME_H
 #include <linux/videodev.h>
+#include <gst/gst.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define GST_TYPE_V4LELEMENT \
   (gst_v4lelement_get_type())
@@ -53,6 +52,8 @@ extern "C" {
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_V4LELEMENT))
 #define GST_IS_V4LELEMENT_CLASS(obj) \
   (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_V4LELEMENT))
+#define GST_V4LELEMENT_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_V4LELEMENT, GstV4lElementClass))
 
 typedef struct _GstV4lElement GstV4lElement;
 typedef struct _GstV4lElementClass GstV4lElementClass;
@@ -91,6 +92,9 @@ struct _GstV4lElement {
 struct _GstV4lElementClass {
   GstElementClass parent_class;
 
+  /* probed devices */
+  GList *devices;
+
   /* signals */
   void     (*open)           (GstElement  *element,
                               const gchar *device);
@@ -108,10 +112,7 @@ struct _GstV4lElementClass {
 
 GType gst_v4lelement_get_type(void);
 
-gboolean gst_v4lelement_factory_init (GstPlugin *plugin);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __GST_V4LELEMENT_H__ */
