@@ -22,9 +22,7 @@
 
 #include <gstv4lelement.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define GST_TYPE_V4LSRC \
   (gst_v4lsrc_get_type())
@@ -40,51 +38,69 @@ extern "C" {
 typedef struct _GstV4lSrc GstV4lSrc;
 typedef struct _GstV4lSrcClass GstV4lSrcClass;
 
+enum {
+  QUEUE_STATE_ERROR = -1,
+  QUEUE_STATE_READY_FOR_QUEUE,
+  QUEUE_STATE_QUEUED,
+  QUEUE_STATE_SYNCED,
+};
+
 struct _GstV4lSrc {
   GstV4lElement v4lelement;
 
   /* pads */
   GstPad *srcpad;
 
-  /* bufferpool for the buffers we're gonna use */
-  GstBufferPool *bufferpool;
-
   /* capture/buffer info */
   struct video_mmap mmap;
   struct video_mbuf mbuf;
-  gint sync_frame;
-  gint8 *frame_queued;
   guint buffer_size;
+  GstClockTime timestamp_sync;
 
-  /* a seperate GThread for the sync() thread (improves correctness of timestamps) */
-  gint8 *isready_soft_sync; /* 1 = ok, 0 = waiting, -1 = error */
-  struct timeval *timestamp_soft_sync;
-  GThread * thread_soft_sync;
-  GMutex * mutex_soft_sync;
-  GCond ** cond_soft_sync;
+  /* num of queued frames and some GThread stuff
+   * to wait if there's not enough */
+  gint8 *frame_queue_state;
+  GMutex *mutex_queue_state;
+  GCond *cond_queue_state;
+  gint num_queued;
+  gint sync_frame, queue_frame;
+  gboolean is_capturing;
 
-  /* num of queued frames and some GThread stuff to wait if there's not enough */
-  guint16 num_queued_frames;
-  GMutex * mutex_queued_frames;
-  GCond * cond_queued_frames;
+  /* True if we want to stop */
+  gboolean quit;
 
-  /* first timestamp */
-  guint64 first_timestamp;
+  /* A/V sync... frame counter and internal cache */
+  gulong handled;
+  gint last_frame;
+  gint need_writes;
 
-  /* caching values */
-  gint width;
-  gint height;
-  gint palette;
+  /* clock */
+  GstClock *clock;
+
+  /* time to substract from clock time to get back to timestamp */
+  GstClockTime substract_time;
+
+  /* how often are we going to use each frame? */
+  gint *use_num_times;
+
+  /* list of supported colourspaces (as integers) */
+  GList *colourspaces;
+
+  /* how are we going to push buffers? */
+  gboolean use_fixed_fps;
 };
 
 struct _GstV4lSrcClass {
   GstV4lElementClass parent_class;
+
+  void (*frame_capture) (GObject *object);
+  void (*frame_drop)    (GObject *object);
+  void (*frame_insert)  (GObject *object);
 };
 
 GType gst_v4lsrc_get_type(void);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+
+G_END_DECLS
 
 #endif /* __GST_V4LSRC_H__ */
