@@ -44,41 +44,40 @@
  ******************************************************/
 
 gboolean
-gst_v4l_set_overlay (GstV4lElement *v4lelement)
+gst_v4l_set_overlay (GstV4lElement * v4lelement)
 {
   gchar *buff;
 
   if (v4lelement->display)
-    g_free(v4lelement->display);
-  v4lelement->display = g_strdup(g_getenv("DISPLAY"));
+    g_free (v4lelement->display);
+  v4lelement->display = g_strdup (g_getenv ("DISPLAY"));
 
-  DEBUG("setting display to '%s'", v4lelement->display);
-  GST_V4L_CHECK_NOT_OPEN(v4lelement);
+  DEBUG ("setting display to '%s'", v4lelement->display);
+  GST_V4L_CHECK_NOT_OPEN (v4lelement);
 
   if (!v4lelement->display || v4lelement->display[0] != ':')
     return FALSE;
 
   /* start v4l-conf */
-  buff = g_strdup_printf("v4l-conf -q -c %s -d %s",
-    v4lelement->videodev, v4lelement->display);
+  buff = g_strdup_printf ("v4l-conf -q -c %s -d %s",
+      v4lelement->videodev, v4lelement->display);
 
-  switch (system(buff))
-  {
+  switch (system (buff)) {
     case -1:
       GST_ELEMENT_ERROR (v4lelement, RESOURCE, FAILED,
-                         (_("Could not start v4l-conf.")), GST_ERROR_SYSTEM);
-      g_free(buff);
+          (_("Could not start v4l-conf.")), GST_ERROR_SYSTEM);
+      g_free (buff);
       return FALSE;
     case 0:
       break;
     default:
       GST_ELEMENT_ERROR (v4lelement, RESOURCE, FAILED,
-                         (_("Executing v4l-conf failed.")), GST_ERROR_SYSTEM);
-      g_free(buff);
+          (_("Executing v4l-conf failed.")), GST_ERROR_SYSTEM);
+      g_free (buff);
       return FALSE;
   }
 
-  g_free(buff);
+  g_free (buff);
   return TRUE;
 }
 
@@ -90,21 +89,16 @@ gst_v4l_set_overlay (GstV4lElement *v4lelement)
  ******************************************************/
 
 gboolean
-gst_v4l_set_window (GstElement        *element,
-                    gint               x,
-                    gint               y,
-                    gint               w,
-                    gint               h,
-                    struct video_clip *clips,
-                    gint               num_clips)
+gst_v4l_set_window (GstElement * element,
+    gint x, gint y, gint w, gint h, struct video_clip * clips, gint num_clips)
 {
-  GstV4lElement *v4lelement = GST_V4LELEMENT(element);
+  GstV4lElement *v4lelement = GST_V4LELEMENT (element);
   struct video_window vwin;
 
-  DEBUG("setting video window to position (x,y/wxh) = %d,%d/%dx%d",
-    x, y, w, h);
-  GST_V4L_CHECK_OPEN(v4lelement);
-  GST_V4L_CHECK_OVERLAY(v4lelement);
+  DEBUG ("setting video window to position (x,y/wxh) = %d,%d/%dx%d",
+      x, y, w, h);
+  GST_V4L_CHECK_OPEN (v4lelement);
+  GST_V4L_CHECK_OVERLAY (v4lelement);
 
   vwin.x = x;
   vwin.y = y;
@@ -112,22 +106,18 @@ gst_v4l_set_window (GstElement        *element,
   vwin.height = h;
   vwin.flags = 0;
 
-  if (clips && !(v4lelement->vcap.type & VID_TYPE_CLIPPING))
-  {
-    DEBUG("Device \'%s\' doesn't do clipping",
-      v4lelement->videodev?v4lelement->videodev:"/dev/video");
+  if (clips && !(v4lelement->vcap.type & VID_TYPE_CLIPPING)) {
+    DEBUG ("Device \'%s\' doesn't do clipping",
+        v4lelement->videodev ? v4lelement->videodev : "/dev/video");
     vwin.clips = 0;
-  }
-  else
-  {
+  } else {
     vwin.clips = clips;
     vwin.clipcount = num_clips;
   }
 
-  if (ioctl(v4lelement->video_fd, VIDIOCSWIN, &vwin) < 0)
-  {
+  if (ioctl (v4lelement->video_fd, VIDIOCSWIN, &vwin) < 0) {
     GST_ELEMENT_ERROR (v4lelement, RESOURCE, TOO_LAZY, (NULL),
-      ("Failed to set the video window: %s", g_strerror (errno)));
+        ("Failed to set the video window: %s", g_strerror (errno)));
     return FALSE;
   }
 
@@ -142,20 +132,18 @@ gst_v4l_set_window (GstElement        *element,
  ******************************************************/
 
 gboolean
-gst_v4l_enable_overlay (GstV4lElement *v4lelement,
-                        gboolean       enable)
+gst_v4l_enable_overlay (GstV4lElement * v4lelement, gboolean enable)
 {
-  gint doit = enable?1:0;
+  gint doit = enable ? 1 : 0;
 
-  DEBUG("%s overlay", enable?"enabling":"disabling");
-  GST_V4L_CHECK_OPEN(v4lelement);
-  GST_V4L_CHECK_OVERLAY(v4lelement);
+  DEBUG ("%s overlay", enable ? "enabling" : "disabling");
+  GST_V4L_CHECK_OPEN (v4lelement);
+  GST_V4L_CHECK_OVERLAY (v4lelement);
 
-  if (ioctl(v4lelement->video_fd, VIDIOCCAPTURE, &doit) < 0)
-  {
+  if (ioctl (v4lelement->video_fd, VIDIOCCAPTURE, &doit) < 0) {
     GST_ELEMENT_ERROR (v4lelement, RESOURCE, TOO_LAZY, (NULL),
-      ("Failed to %s overlay display: %s",
-      enable?"enable":"disable", g_strerror (errno)));
+        ("Failed to %s overlay display: %s",
+            enable ? "enable" : "disable", g_strerror (errno)));
     return FALSE;
   }
 
